<?php
/**
 * Pithree blog function
 *
 * @package WordPress
 * @subpackage Pithree
 * @since Pithree 1.0
 */
//////////////////////////////////////////////////////////////////
// Paging Navigation
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_paging_navigation')) {
	function g5plus_paging_navigation() {
		g5plus_get_template('paging/navigation');
	}
}

//////////////////////////////////////////////////////////////////
// Paging Load More
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_paging_load_more')) {
	function g5plus_paging_load_more() {
		g5plus_get_template('paging/load-more');
	}
}

//////////////////////////////////////////////////////////////////
// Paging Infinite Scroll
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_paging_infinite_scroll')) {
	function g5plus_paging_infinite_scroll() {
		g5plus_get_template('paging/infinite-scroll');
	}
}

//////////////////////////////////////////////////////////////////
// Get Post Thumb
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_post_thumbnail')) {
	function g5plus_get_post_thumbnail($size,$noImage = 0) {
		$args = array(
			'size' => $size,
			'noImage' => $noImage
		);
		g5plus_get_template('archive/thumbnail',$args);
	}
}

//////////////////////////////////////////////////////////////////
// Get Post Thumbnail
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_post_image')) {
	function g5plus_get_post_image($image_id,$size,$gallery = 0) {
		$image_src = g5plus_get_image_src($image_id,$size);
		if (!empty($image_src)) {
			g5plus_get_image_hover($image_id,$image_src,$size,get_permalink(),the_title_attribute('echo=0'),get_the_ID(),$gallery);
		}
	}
}

//////////////////////////////////////////////////////////////////
// Get Image Size
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_image_size')) {
	function g5plus_get_image_size() {
		return apply_filters('g5plus_image_size',array(
			'large-image' => array(
				'width' => 1170,
				'height' => 495
			),
			'medium-image' => array(
				'width' => 570,
				'height' => 320
			),
			'small-image' => array(
				'width' => 120,
				'height' => 94
			),
			'services-image' => array(
				'width' => 360,
				'height' => 247
			)
		));
	}
}

//////////////////////////////////////////////////////////////////
// Get Image Src
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_image_src')) {
	function g5plus_get_image_src($image_id,$size) {
		$image_src = '';
		$image_sizes = g5plus_get_image_size();
		if (isset($image_sizes[$size])) {
			$width = $image_sizes[$size]['width'];
			$height = $image_sizes[$size]['height'];
			$image_src = matthewruddy_image_resize_id($image_id,$width,$height);
		}else {
			$image_src_arr = wp_get_attachment_image_src( $image_id, $size );
			if ($image_src_arr) {
				$image_src = $image_src_arr[0];
			}
		}
		return $image_src;
	}
}

//////////////////////////////////////////////////////////////////
// Get Image Hover
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_image_hover')) {
	function g5plus_get_image_hover($image_id, $image_src, $size, $link, $title, $post_id,$gallery = 0) {
		$image_full_arr = wp_get_attachment_image_src($image_id,'full');
		$image_full_src = $image_src;
		if ($image_full_arr) {
			$image_full_src = $image_full_arr[0];
		}
		$width = '';
		$height = '';
		$image_sizes = g5plus_get_image_size();
		if (isset($image_sizes[$size])) {
			$width = $image_sizes[$size]['width'];
			$height = $image_sizes[$size]['height'];
		} else {
			$_wp_additional_image_sizes = get_intermediate_image_sizes();
			if ( in_array( $size, array( 'thumbnail', 'medium', 'large' ) ) ) {
				$width = get_option( $size . '_size_w' );
				$height = get_option( $size . '_size_h' );
			} elseif ( isset( $_wp_additional_image_sizes[ $size ] ) ) {
				$width = $_wp_additional_image_sizes[ $size ]['width'];
				$height = $_wp_additional_image_sizes[ $size ]['height'];
			}
		}
		$prettyPhoto = 'prettyPhoto';
		if ($gallery == 1) {
			$prettyPhoto='prettyPhoto[gallery_'.$post_id.']';
		}
		$args = array(
			'image_src' => $image_src,
			'image_full_src' => $image_full_src,
			'width' => $width,
			'height' => $height,
			'link' => $link,
			'title' => $title,
		);
		g5plus_get_template('archive/image-hover',$args);
	}
}

//////////////////////////////////////////////////////////////////
// Display Post Meta
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_the_post_meta')) {
	function g5plus_the_post_meta() {
		g5plus_get_template('archive/post-meta');
	}
}

//////////////////////////////////////////////////////////////////
// Display Social Share
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_the_social_share')) {
	function g5plus_the_social_share() {
		g5plus_get_template('social-share');
	}
}

//////////////////////////////////////////////////////////////////
// Single Post Navigation
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_post_nav')) {
	function g5plus_post_nav() {
		g5plus_get_template('single/post-nav');
	}
	add_action('g5plus_after_single_post','g5plus_post_nav',10);
}

//////////////////////////////////////////////////////////////////
// Author Info
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_post_author_info')) {
	function g5plus_post_author_info() {
		g5plus_get_template('single/author-info');
	}
	add_action('g5plus_after_single_post','g5plus_post_author_info',15);
}


//////////////////////////////////////////////////////////////////
// Post Comment
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_post_comment')) {
	function g5plus_post_comment() {
		if ( comments_open() || get_comments_number() ) {
			comments_template();
		}
	}
	add_action('g5plus_after_single_post','g5plus_post_comment',20);
}

//////////////////////////////////////////////////////////////////
// Related Post
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_post_related')) {
	function g5plus_post_related() {
		g5plus_get_template('single/related');
	}
	add_action('g5plus_after_single_post','g5plus_post_related',30);
}

//////////////////////////////////////////////////////////////////
// Get Related Post
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_related_post')) {
	function g5plus_get_related_post($post_id) {
		$related_posts = array();
		$tags_array = g5plus_get_related_terms( $post_id,'post_tag' );
		$cats_array = g5plus_get_related_terms( $post_id,'category' );
		if ((sizeof($tags_array) > 1) || (sizeof($cats_array) > 1)) {
			$wpdb = &G5Plus_Global::get_wpdb();
			$query = g5plus_build_related_post_query( $post_id, $cats_array, $tags_array );
			// Get the posts
			$related_posts = $wpdb->get_col( implode( ' ', $query ));
		}
		return $related_posts;
	}
}

//////////////////////////////////////////////////////////////////
// Get Related Terms
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_get_related_terms')) {
	function g5plus_get_related_terms($post_id,$term) {
		$terms_array = array(0);
		$terms = apply_filters( 'g5plus_get_related_' . $term . '_terms', wp_get_post_terms( $post_id, $term ), $post_id );
		foreach ( $terms as $term ) {
			$terms_array[] = $term->term_id;
		}
		return array_map( 'absint', $terms_array );
	}
}

//////////////////////////////////////////////////////////////////
// Build Query Related Post
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_build_related_post_query')) {
	function g5plus_build_related_post_query($post_id, $cats_array, $tags_array) {
		$g5plus_options = G5Plus_Global::get_options();
		$wpdb = &G5Plus_Global::get_wpdb();
		$query           = array();
		$query['fields'] = "SELECT DISTINCT ID FROM {$wpdb->posts} p";
		$query['join']  = " INNER JOIN {$wpdb->term_relationships} tr ON (p.ID = tr.object_id)";
		$query['join']  .= " INNER JOIN {$wpdb->term_taxonomy} tt ON (tr.term_taxonomy_id = tt.term_taxonomy_id)";
		$query['join']  .= " INNER JOIN {$wpdb->terms} t ON (t.term_id = tt.term_id)";

		$query['where']  = " WHERE 1=1";
		$query['where'] .= " AND p.post_status = 'publish'";
		$query['where'] .= " AND p.post_type = 'post'";
		$query['where'] .= " AND p.ID <> {$post_id}";

		$related_by_category = $g5plus_options['single_related_post_condition']['category'] == 1 ? true : false;

		if ( apply_filters( 'g5plus_post_related_posts_relate_by_category', $related_by_category, $post_id ) ) {
			$query['where'] .= " AND ( ( tt.taxonomy = 'category' AND t.term_id IN ( " . implode( ',', $cats_array ) . " ) )";
			$andor = 'OR';
		} else {
			$andor = 'AND';
		}

		$related_by_tag =  $g5plus_options['single_related_post_condition']['tag'] == 1 ? true : false;

		if ( apply_filters( 'g5plus_post_related_posts_relate_by_tag', $related_by_tag, $post_id ) ) {
			$query['where'] .= " {$andor}  ( tt.taxonomy = 'post_tag' AND t.term_id IN ( " . implode( ',', $tags_array ) . " ) )";
		}

		if ( apply_filters( 'g5plus_post_related_posts_relate_by_category', true, $post_id ) ) {
			$query['where'] .= ")";
		}

		$query           = apply_filters( 'g5plus_post_related_posts_query', $query, $post_id );
		return $query;

	}
}

//////////////////////////////////////////////////////////////////
// Get Limit Word
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_string_limit_words')) {
	function g5plus_string_limit_words($string, $word_limit)
	{
		$words = explode(' ', $string, ($word_limit + 1));

		if(count($words) > $word_limit) {
			array_pop($words);
		}

		return implode(' ', $words);
	}
}

//////////////////////////////////////////////////////////////////
// Render Comment
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_render_comments')) {
	function g5plus_render_comments($comment, $args, $depth) {
		g5plus_get_template('single/comment',array('comment' => $comment, 'args' => $args, 'depth' => $depth));
	}
}
//////////////////////////////////////////////////////////////////
// Comments Form
//////////////////////////////////////////////////////////////////
if (!function_exists('g5plus_comment_form')) {
	function g5plus_comment_form() {
		$commenter = wp_get_current_commenter();
		$req = get_option('require_name_email');
		$aria_req = ($req ? " aria-required='true'" : '');
		$html5 = current_theme_supports('html5', 'comment-form') ? 'html5' : 'xhtml';;
		$fields = array(
			'author' => '<div class="form-group col-md-12">' .
				'<input id="author" name="author" type="text" value="' . esc_attr($commenter['comment_author']) . '" placeholder="'.esc_html__('Name*','pithree').'" ' . $aria_req . '>' .
				'</div>',
			'email' => '<div class="form-group col-md-12">' .
				'<input id="email" name="email" ' . ($html5 ? 'type="email"' : 'type="text"') . ' value="' . esc_attr($commenter['comment_author_email']) . '" placeholder="'.esc_html__('Email*','pithree').'" ' . $aria_req . '>' .
				'</div>',
			'url'   => '<div class="form-group col-md-12">'.
				'<input id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" placeholder="'.esc_html__('Website','pithree').'" />'.
				'</div>'
		);
		$fields = apply_filters('g5plus_comment_fields',$fields);
		$comment_form_args = array(
			'fields' => $fields,
			'comment_field' => '<div class="form-group">' .
				'<textarea rows="6" id="comment" name="comment" placeholder="'.esc_html__('Message*','pithree') .'" '. $aria_req .'></textarea>' .
				'</div>',
			'comment_notes_before' => '<p class="comment-notes">' .
				esc_html__('Your email address will not be published.', 'pithree') /* . ( $req ? $required_text : '' ) */ .
				'</p>',
			'comment_notes_after' => '',
			'id_submit' => 'btnComment',
			'class_submit' => 'button-comment',
			'title_reply' => esc_html__('Write a Message', 'pithree'),
			'title_reply_to' => esc_html__('Write a Message to %s', 'pithree'),
			'cancel_reply_link' => esc_html__('Cancel Reply', 'pithree'),
			'label_submit' => esc_html__('Send Message', 'pithree')
		);

		$comment_form_args = apply_filters('g5plus_comment_form_args',$comment_form_args);

		comment_form($comment_form_args);
	}
}


