<?php
/*
*
*	Meta Box Functions
*	------------------------------------------------
*	G5Plus Framework
* 	Copyright Swift Ideas 2015 - http://www.g5plus.net
*
*/
/********************* META BOX REGISTERING ***********************/

/**
 * Register meta boxes
 *
 * @return void
 */
function g5plus_register_meta_boxes()
{
	$meta_boxes = &G5Plus_Global::get_meta_boxes();
	$prefix = G5PLUS_METABOX_PREFIX;
	/* PAGE MENU */
	$menu_list = array();
	if (function_exists('g5plus_get_menu_list')) {
		$menu_list = g5plus_get_menu_list();
	}

	// PAGE LAYOUT
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_layout_meta_box',
		'title'      => esc_html__('Page Layout', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product', 'services'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'     => esc_html__('Layout Style', 'pithree'),
				'id'       => $prefix . 'layout_style',
				'type'     => 'button_set',
				'options'  => array(
					'-1'    => esc_html__('Default', 'pithree'),
					'boxed' => esc_html__('Boxed', 'pithree'),
					'wide'  => esc_html__('Wide', 'pithree')
				),
				'std'      => '-1',
				'multiple' => false,
			),
			array(
				'name'     => esc_html__('Layout', 'pithree'),
				'id'       => $prefix . 'layout',
				'type'     => 'button_set',
				'options'  => g5plus_get_page_layout(1),
				'std'      => -1,
				'multiple' => false,
			),
			array(
				'name'       => esc_html__('Sidebar Layout', 'pithree'),
				'id'         => $prefix . 'sidebar_layout',
				'type'       => 'image_set',
				'allowClear' => true,
				'options'    => array(
					'none'  => G5PLUS_THEME_URL . '/assets/images/theme-options/sidebar-none.png',
					'left'  => G5PLUS_THEME_URL . '/assets/images/theme-options/sidebar-left.png',
					'right' => G5PLUS_THEME_URL . '/assets/images/theme-options/sidebar-right.png'
				),
				'std'        => '',
				'multiple'   => false,

			),
			array(
				'name'           => esc_html__('Sidebar', 'pithree'),
				'id'             => $prefix . 'sidebar',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array($prefix . 'sidebar_layout', '=', array('', 'right', 'left')),
			),

			array(
				'name'           => esc_html__('Sidebar Width', 'pithree'),
				'id'             => $prefix . 'sidebar_width',
				'type'           => 'button_set',
				'options'        => g5plus_get_sidebar_width(1),
				'std'            => -1,
				'multiple'       => false,
				'required-field' => array($prefix . 'sidebar_layout', '<>', 'none'),
			),

			array(
				'name'           => esc_html__('Sidebar Mobile', 'pithree'),
				'id'             => $prefix . 'sidebar_mobile_enable',
				'type'           => 'button_set',
				'options'        => g5plus_get_toggle(true),
				'std'            => -1,
				'multiple'       => false,
				'required-field' => array($prefix . 'sidebar_layout', '<>', 'none'),
			),

			array(
				'name' => esc_html__('Remove Content Padding', 'pithree'),
				'id'   => $prefix . 'remove_content_padding',
				'type' => 'checkbox',
				'std'  => 0,
			),

			array(
				'name' => esc_html__('Page Class Extra', 'pithree'),
				'id'   => $prefix . 'page_class_extra',
				'type' => 'text',
				'std'  => ''
			),
		)
	);

	// LOGO
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_logo_meta_box',
		'title'      => esc_html__('Logo', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name' => esc_html__('Desktop Settings', 'pithree'),
				'id'   => $prefix . 'page_logo_section_1',
				'type' => 'section',
				'std'  => '',
			),
			array(
				'id'               => $prefix . 'logo',
				'name'             => esc_html__('Header Logo', 'pithree'),
				'desc'             => esc_html__('Upload custom logo in header.', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'               => $prefix . 'logo_retina',
				'name'             => esc_html__('Header Logo Retina', 'pithree'),
				'desc'             => esc_html__('Upload custom logo retina in header.', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'               => $prefix . 'sticky_logo',
				'name'             => esc_html__('Sticky Logo', 'pithree'),
				'desc'             => esc_html__('Upload sticky logo in header (empty to default)', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'               => $prefix . 'sticky_logo_retina',
				'name'             => esc_html__('Sticky Logo Retina', 'pithree'),
				'desc'             => esc_html__('Upload sticky logo retina in header (empty to default)', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'   => $prefix . 'logo_max_height',
				'name' => esc_html__('Logo max height', 'pithree'),
				'desc' => esc_html__('Logo max height (px). Do not include units (empty to set default)', 'pithree'),
				'type' => 'text',
				'sdt'  => '',
			),
			array(
				'id'    => $prefix . 'logo_padding',
				'name'  => esc_html__('Logo padding', 'pithree'),
				'desc'  => esc_html__('Logo padding top. Do not include units (empty to set default)', 'pithree'),
				'type'  => 'padding',
				'allow' => array(
					'left'  => false,
					'right' => false
				),
			),

			array(
				'name' => esc_html__('Mobile Settings', 'pithree'),
				'id'   => $prefix . 'page_logo_section_2',
				'type' => 'section',
				'std'  => '',
			),
			array(
				'id'               => $prefix . 'mobile_logo',
				'name'             => esc_html__('Mobile Logo', 'pithree'),
				'desc'             => esc_html__('Upload mobile logo in header.', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'               => $prefix . 'mobile_logo_retina',
				'name'             => esc_html__('Mobile Logo Retina', 'pithree'),
				'desc'             => esc_html__('Upload mobile logo retina in header.', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
			),
			array(
				'id'   => $prefix . 'mobile_logo_max_height',
				'name' => esc_html__('Mobile Logo Max Height', 'pithree'),
				'desc' => esc_html__('Logo max height (px). Do not include units (empty to set default)', 'pithree'),
				'type' => 'text',
				'sdt'  => '',
			),
			array(
				'id'    => $prefix . 'mobile_logo_padding',
				'name'  => esc_html__('Mobile logo padding', 'pithree'),
				'desc'  => esc_html__('Mobile logo padding top. Do not include units (empty to set default)', 'pithree'),
				'type'  => 'padding',
				'allow' => array(
					'left'  => false,
					'right' => false
				),
			),
		)
	);

	// TOP DRAWER
	$meta_boxes[] = array(
		'id'         => $prefix . 'top_drawer_meta_box',
		'title'      => esc_html__('Top drawer', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'    => esc_html__('Top Drawer Type', 'pithree'),
				'id'      => $prefix . 'top_drawer_type',
				'type'    => 'button_set',
				'std'     => '-1',
				'options' => array(
					'-1'     => esc_html__('Default', 'pithree'),
					'none'   => esc_html__('Disable', 'pithree'),
					'show'   => esc_html__('Always Show', 'pithree'),
					'toggle' => esc_html__('Toggle', 'pithree')
				),
				'desc'    => esc_html__('Top drawer type', 'pithree'),
			),
			array(
				'name'           => esc_html__('Top Drawer Sidebar', 'pithree'),
				'id'             => $prefix . 'top_drawer_sidebar',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array($prefix . 'top_drawer_type', '<>', 'none'),
			),

			array(
				'name'           => esc_html__('Top Drawer Wrapper Layout', 'pithree'),
				'id'             => $prefix . 'top_drawer_wrapper_layout',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'              => esc_html__('Default', 'pithree'),
					'full'            => esc_html__('Full Width', 'pithree'),
					'container'       => esc_html__('Container', 'pithree'),
					'container-fluid' => esc_html__('Container Fluid', 'pithree')
				),
				'required-field' => array($prefix . 'top_drawer_type', '<>', 'none'),
			),

			array(
				'name'           => esc_html__('Top Drawer hide on mobile', 'pithree'),
				'id'             => $prefix . 'top_drawer_hide_mobile',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Show on mobile', 'pithree'),
					'0'  => esc_html__('Hide on mobile', 'pithree'),
				),
				'required-field' => array($prefix . 'top_drawer_type', '<>', 'none'),
			),
			array(
				'id'    => $prefix . 'top_drawer_padding',
				'name'  => esc_html__('Top drawer padding', 'pithree'),
				'desc'  => esc_html__('Top drawer padding top. Do not include units (empty to set default)', 'pithree'),
				'type'  => 'padding',
				'allow' => array(
					'left'  => false,
					'right' => false
				),
			),
		)
	);

	// TOP BAR
	$meta_boxes[] = array(
		'id'         => $prefix . 'top_bar_meta_box',
		'title'      => esc_html__('Top Bar', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name' => esc_html__('Desktop Settings', 'pithree'),
				'id'   => $prefix . 'top_bar_desktop_section',
				'type' => 'section',
				'std'  => 0,
			),
			array(
				'name'    => esc_html__('Show/Hide Top Bar', 'pithree'),
				'id'      => $prefix . 'top_bar_enable',
				'type'    => 'button_set',
				'std'     => '-1',
				'options' => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Show', 'pithree'),
					'0'  => esc_html__('Hide', 'pithree')
				),
				'desc'    => esc_html__('Show/Hide Top Bar.', 'pithree'),
			),

			array(
				'name'           => esc_html__('Top Bar Layout', 'pithree'),
				'id'             => $prefix . 'top_bar_layout',
				'type'           => 'image_set',
				'width'          => '80px',
				'allowClear'     => true,
				'std'            => '',
				'options'        => array(
					'top-bar-1' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-1.jpg',
					'top-bar-2' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-2.jpg',
					'top-bar-3' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-3.jpg',
					'top-bar-4' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-4.jpg'
				),
				'required-field' => array(
					array($prefix . 'top_bar_enable', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Top Left Sidebar', 'pithree'),
				'id'             => $prefix . 'top_bar_left_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_enable', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Top Right Sidebar', 'pithree'),
				'id'             => $prefix . 'top_bar_right_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_enable', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Top Bar Border', 'pithree'),
				'id'             => $prefix . 'top_bar_border',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'               => esc_html__('Default', 'pithree'),
					'none'             => esc_html__('None', 'pithree'),
					'full-border'      => esc_html__('Full Border', 'pithree'),
					'container-border' => esc_html__('Container Border', 'pithree'),
				),
				'desc'           => esc_html__('Show Hide Top Bar.', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_enable', '<>', '0'),
				),
			),
			array(
				'id'             => $prefix . 'top_bar_padding',
				'name'           => esc_html__('Top bar padding', 'pithree'),
				'desc'           => esc_html__('Top bar padding top. Do not include units (empty to set default)', 'pithree'),
				'type'           => 'padding',
				'allow'          => array(
					'left'  => false,
					'right' => false
				),
				'required-field' => array(
					array($prefix . 'top_bar_enable', '<>', '0'),
				),
			),

			array(
				'name' => esc_html__('Mobile Settings', 'pithree'),
				'id'   => $prefix . 'top_bar_mobile_section',
				'type' => 'section',
				'std'  => '',
			),
			array(
				'name'    => esc_html__('Show/Hide Top Bar', 'pithree'),
				'id'      => $prefix . 'top_bar_mobile_enable',
				'type'    => 'button_set',
				'options' => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Show', 'pithree'),
					'0'  => esc_html__('Hide', 'pithree')
				),
				'std'     => '-1',
				'desc'    => esc_html__('Show/Hide Top Bar.', 'pithree'),
			),
			array(
				'name'           => esc_html__('Top Bar Layout', 'pithree'),
				'id'             => $prefix . 'top_bar_mobile_layout',
				'type'           => 'image_set',
				'width'          => '80px',
				'allowClear'     => true,
				'std'            => '',
				'options'        => array(
					'top-bar-1' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-1.jpg',
					'top-bar-2' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-2.jpg',
					'top-bar-3' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-3.jpg',
					'top-bar-4' => G5PLUS_THEME_URL . 'assets/images/theme-options/top-bar-layout-4.jpg'
				),
				'required-field' => array(
					array($prefix . 'top_bar_mobile_enable', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Top Left Sidebar', 'pithree'),
				'id'             => $prefix . 'top_bar_mobile_left_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_mobile_enable', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Top Right Sidebar', 'pithree'),
				'id'             => $prefix . 'top_bar_mobile_right_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_mobile_enable', '<>', '0'),
				),
			),
			array(
				'name'           => esc_html__('Top Bar Border', 'pithree'),
				'id'             => $prefix . 'top_bar_mobile_border',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'               => esc_html__('Default', 'pithree'),
					'none'             => esc_html__('None', 'pithree'),
					'full-border'      => esc_html__('Full Border', 'pithree'),
					'container-border' => esc_html__('Container Border', 'pithree'),
				),
				'desc'           => esc_html__('Show Hide Top Bar.', 'pithree'),
				'required-field' => array(
					array($prefix . 'top_bar_mobile_enable', '<>', '0'),
				),
			),
		)
	);

	// PAGE HEADER
	//--------------------------------------------------
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_header_meta_box',
		'title'      => esc_html__('Page Header', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name' => esc_html__('Header On/Off?', 'pithree'),
				'id'   => $prefix . 'header_show_hide',
				'type' => 'checkbox',
				'desc' => esc_html__('Turn ON/Off Header', 'pithree'),
				'std'  => '1',
			),
			array(
				'name'           => esc_html__('Desktop Settings', 'pithree'),
				'id'             => $prefix . 'page_header_customize_enable',
				'type'           => 'section',
				'std'            => '',
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'name'           => esc_html__('Header Layout', 'pithree'),
				'id'             => $prefix . 'header_layout',
				'type'           => 'image_set',
				'allowClear'     => true,
				'std'            => '',
				'options'        => array(
					'header-1'  => G5PLUS_THEME_URL . '/assets/images/theme-options/header-1.png',
					'header-2'  => G5PLUS_THEME_URL . '/assets/images/theme-options/header-2.png',
					'header-3'  => G5PLUS_THEME_URL . '/assets/images/theme-options/header-3.png',
					'header-4'  => G5PLUS_THEME_URL . '/assets/images/theme-options/header-4.png',
					'header-5'  => G5PLUS_THEME_URL . '/assets/images/theme-options/header-5.png',
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'header_container_layout',
				'name'           => esc_html__('Header Container Layout', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'             => esc_html__('Default', 'pithree'),
					'container'      => esc_html__('Container', 'pithree'),
					'container-full' => esc_html__('Container Full', 'pithree'),
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'header_float',
				'name'           => esc_html__('Header Float', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('On', 'pithree'),
					'0'  => esc_html__('Off', 'pithree'),
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'header_sticky',
				'name'           => esc_html__('Show/Hide Header Sticky', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('On', 'pithree'),
					'0'  => esc_html__('Off', 'pithree')
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'header_border_bottom',
				'name'           => esc_html__('Header border bottom', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'           		=> esc_html__('Default', 'pithree'),
					'none'              => esc_html__('None','pithree'),
					'full-border'       => esc_html__('Full Border','pithree'),
					'container-border'  => esc_html__('Container Border','pithree'),
				),
				'required-field' => array(
					array($prefix . 'header_show_hide', '<>', '0'),
					array($prefix . 'header_layout', '=', array('header-1', 'header-3')),
				),
			),
			array(
				'id'             => $prefix . 'header_above_border_bottom',
				'name'           => esc_html__('Header above border bottom', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'           		=> esc_html__('Default', 'pithree'),
					'none'              => esc_html__('None','pithree'),
					'full-border'       => esc_html__('Full Border','pithree'),
					'container-border'  => esc_html__('Container Border','pithree'),
				),
				'required-field' => array(
					array($prefix . 'header_show_hide', '<>', '0'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'id'             => $prefix . 'header_padding',
				'name'           => esc_html__('Header padding', 'pithree'),
				'desc'           => esc_html__('Header padding top. Do not include units (empty to set default)', 'pithree'),
				'type'           => 'padding',
				'allow'          => array(
					'left'  => false,
					'right' => false
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'navigation_height',
				'name'           => esc_html__('Navigation height', 'pithree'),
				'type'           => 'text',
				'desc'           => esc_html__('Set header navigation height (px). Do not include unit.', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'header_show_hide', '<>', '0'),
					array($prefix . 'header_layout', '<>', 'header-1')
				),
			),

			//-----------------------------------------------------------------------
			array(
				'name'           => esc_html__('Page Header Mobile', 'pithree'),
				'id'             => $prefix . 'page_header_section_2',
				'type'           => 'section',
				'std'            => '',
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'name'           => esc_html__('Header Mobile Layout', 'pithree'),
				'id'             => $prefix . 'mobile_header_layout',
				'type'           => 'image_set',
				'allowClear'     => true,
				'std'            => '',
				'options'        => array(
					'header-mobile-1' => G5PLUS_THEME_URL . 'assets/images/theme-options/header-mobile-layout-1.png',
					'header-mobile-2' => G5PLUS_THEME_URL . 'assets/images/theme-options/header-mobile-layout-2.png',
					'header-mobile-3' => G5PLUS_THEME_URL . 'assets/images/theme-options/header-mobile-layout-3.png',
					'header-mobile-4' => G5PLUS_THEME_URL . 'assets/images/theme-options/header-mobile-layout-4.png',
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'mobile_header_menu_drop',
				'name'           => esc_html__('Menu Drop Type', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'                 => esc_html__('Default', 'pithree'),
					'menu-drop-dropdown' => esc_html__('Dropdown Menu', 'pithree'),
					'menu-drop-fly'      => esc_html__('Fly Menu', 'pithree'),
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'mobile_header_stick',
				'name'           => esc_html__('Header mobile sticky', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Enable', 'pithree'),
					'0'  => esc_html__('Disable', 'pithree'),
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'name'           => esc_html__('Mobile Header Search Box', 'pithree'),
				'id'             => $prefix . 'mobile_header_search_box',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Show', 'pithree'),
					'0'  => esc_html__('Hide', 'pithree')
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),

			array(
				'name'           => esc_html__('Mobile Header Shopping Cart', 'pithree'),
				'id'             => $prefix . 'mobile_header_shopping_cart',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => esc_html__('Show', 'pithree'),
					'0'  => esc_html__('Hide', 'pithree')
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'mobile_header_border_bottom',
				'name'           => esc_html__('Mobile header border bottom', 'pithree'),
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'       => esc_html__('Default', 'pithree'),
					'none'     => esc_html__('None', 'pithree'),
					'bordered' => esc_html__('Bordered', 'pithree'),
				),
				'required-field' => array($prefix . 'header_show_hide', '<>', '0'),
			),
		)
	);

	// HEADER CUSTOMIZE
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_header_customize_meta_box',
		'title'      => esc_html__('Page Header Customize', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'   => esc_html__('Header Customize Navigation', 'pithree'),
				'id'     => $prefix . 'enable_header_customize_nav',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Header Customize Navigation', 'pithree'),
				'id'             => $prefix . 'header_customize_nav',
				'type'           => 'sorter',
				'std'            => '',
				'desc'           => esc_html__('Select element for header customize navigation. Drag to change element order', 'pithree'),
				'options'        => array(
					'email'         => esc_html__('Email', 'pithree'),
					'phone'         => esc_html__('Phone', 'pithree'),
					'openingtime'         => esc_html__('Opening Time', 'pithree'),
					'shopping-cart' => esc_html__('Shopping Cart', 'pithree'),
					'search' => esc_html__('Search', 'pithree'),
					'sidebar'       => esc_html__('Sidebar', 'pithree'),
					'custom-text'   => esc_html__('Custom Text', 'pithree'),
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Email', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_email',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Email Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Phone', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_phone',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Call Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Opening Time', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_openingtime',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Opening Time', 'pithree'),
					'text'  => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Search Type', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_search',
				'type'           => 'button_set',
				'std'            => 'button',
				'options'        => array(
					'button'           => esc_html__('Button', 'pithree'),
					'box'              => esc_html__('Box', 'pithree'),
					'product-category' => esc_html__('Product Category', 'pithree'),
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Sidebar', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'name'           => esc_html__('Custom text content', 'pithree'),
				'id'             => $prefix . 'header_customize_nav_text',
				'type'           => 'textarea',
				'std'            => '',
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),
			array(
				'id'             => $prefix . 'header_customize_nav_spacing',
				'name'           => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '40',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array($prefix . 'enable_header_customize_nav', '=', '1'),
			),

			//-------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Header Customize Left', 'pithree'),
				'id'     => $prefix . 'enable_header_customize_left',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
				'required-field' => array(
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Header Customize Left', 'pithree'),
				'id'             => $prefix . 'header_customize_left',
				'type'           => 'sorter',
				'std'            => '',
				'desc'           => esc_html__('Select element for header customize left. Drag to change element order', 'pithree'),
				'options'        => array(
					'email'         => esc_html__('Email', 'pithree'),
					'phone'         => esc_html__('Phone', 'pithree'),
					'openingtime'   => esc_html__('Opening Time', 'pithree'),
					'shopping-cart' => esc_html__('Shopping Cart', 'pithree'),
					'search' => esc_html__('Search', 'pithree'),
					'sidebar'       => esc_html__('Sidebar', 'pithree'),
					'custom-text'   => esc_html__('Custom Text', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Email', 'pithree'),
				'id'             => $prefix . 'header_customize_left_email',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Email Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Phone', 'pithree'),
				'id'             => $prefix . 'header_customize_left_phone',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Call Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Opening Time', 'pithree'),
				'id'             => $prefix . 'header_customize_left_openingtime',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Opening Time', 'pithree'),
					'text'  => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Search Type', 'pithree'),
				'id'             => $prefix . 'header_customize_left_search',
				'type'           => 'button_set',
				'std'            => 'button',
				'options'        => array(
					'button'           => esc_html__('Button', 'pithree'),
					'box'              => esc_html__('Box', 'pithree'),
					'product-category' => esc_html__('Product Category', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Sidebar', 'pithree'),
				'id'             => $prefix . 'header_customize_left_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'name'           => esc_html__('Custom text content left', 'pithree'),
				'id'             => $prefix . 'header_customize_left_text',
				'type'           => 'textarea',
				'std'            => '',
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),
			array(
				'id'             => $prefix . 'header_customize_left_spacing',
				'name'           => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '40',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_left', '=', '1'),
					array($prefix . 'header_layout', '=', array('header-3')),
				),
			),

			//------------------------------------------------------------------
			array(
				'name'   => esc_html__('Header Customize Right', 'pithree'),
				'id'     => $prefix . 'enable_header_customize_right',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
				'required-field' => array(
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Header Customize Right', 'pithree'),
				'id'             => $prefix . 'header_customize_right',
				'type'           => 'sorter',
				'std'            => '',
				'desc'           => esc_html__('Select element for header customize right. Drag to change element order', 'pithree'),
				'options'        => array(
					'email'         => esc_html__('Email', 'pithree'),
					'phone'         => esc_html__('Phone', 'pithree'),
					'openingtime'   => esc_html__('Opening Time', 'pithree'),
					'shopping-cart' => esc_html__('Shopping Cart', 'pithree'),
					'search' => esc_html__('Search', 'pithree'),
					'sidebar'       => esc_html__('Sidebar', 'pithree'),
					'custom-text'   => esc_html__('Custom Text', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Email', 'pithree'),
				'id'             => $prefix . 'header_customize_right_email',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Email Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Phone', 'pithree'),
				'id'             => $prefix . 'header_customize_right_phone',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Call Us', 'pithree'),
					'text'  => ''
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Opening Time', 'pithree'),
				'id'             => $prefix . 'header_customize_right_openingtime',
				'type'           => 'label_text',
				'std'            => array(
					'label' => esc_html__('Opening Time', 'pithree'),
					'text'  => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Search Type', 'pithree'),
				'id'             => $prefix . 'header_customize_right_search',
				'type'           => 'button_set',
				'std'            => 'button',
				'options'        => array(
					'button'           => esc_html__('Button', 'pithree'),
					'box'              => esc_html__('Box', 'pithree'),
					'product-category' => esc_html__('Product Category', 'pithree'),
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Sidebar', 'pithree'),
				'id'             => $prefix . 'header_customize_right_sidebar',
				'type'           => 'sidebars',
				'std'            => '',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'name'           => esc_html__('Custom text content right', 'pithree'),
				'id'             => $prefix . 'header_customize_right_text',
				'type'           => 'textarea',
				'std'            => '',
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
			array(
				'id'             => $prefix . 'header_customize_right_spacing',
				'name'           => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '40',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array(
					array($prefix . 'enable_header_customize_right', '=', '1'),
					array($prefix . 'header_layout', '<>', 'header-1'),
				),
			),
		)
	);

	// MENU
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_menu_meta_box',
		'title'      => esc_html__('Menu', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'        => esc_html__('Page menu', 'pithree'),
				'id'          => $prefix . 'page_menu',
				'type'        => 'select_advanced',
				'options'     => $menu_list,
				'placeholder' => esc_html__('Select Menu', 'pithree'),
				'std'         => '',
				'multiple'    => false,
				'desc'        => esc_html__('Optionally you can choose to override the menu that is used on the page', 'pithree'),
			),

			array(
				'name'        => esc_html__('Page menu mobile', 'pithree'),
				'id'          => $prefix . 'page_menu_mobile',
				'type'        => 'select_advanced',
				'options'     => $menu_list,
				'placeholder' => esc_html__('Select Menu', 'pithree'),
				'std'         => '',
				'multiple'    => false,
				'desc'        => esc_html__('Optionally you can choose to override the menu mobile that is used on the page', 'pithree'),
			),

			array(
				'name' => esc_html__('Is One Page', 'pithree'),
				'id'   => $prefix . 'is_one_page',
				'type' => 'checkbox',
				'std'  => '0',
				'desc' => esc_html__('Set page style is One Page', 'pithree'),
			),
		)
	);


	// PAGE TITLE
	//--------------------------------------------------
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_title_meta_box',
		'title'      => esc_html__('Page Title', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'    => esc_html__('Show/Hide Page Title?', 'pithree'),
				'id'      => $prefix . 'page_title_enable',
				'type'    => 'button_set',
				'std'     => -1,
				'options' => g5plus_get_toggle(1)
			),

			array(
				'name'           => esc_html__('Page Title Layout', 'pithree'),
				'id'             => $prefix . 'page_title_layout',
				'type'           => 'button_set',
				'std'            => -1,
				'options'        => g5plus_get_page_title_layout(1),
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),

			array(
				'name'           => esc_html__('Page Title Text Color', 'pithree'),
				'id'             => $prefix . 'page_title_title_color',
				'type'           => 'color',
				'std'            => '',
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),

			array(
				'name'           => esc_html__('Custom Page Title', 'pithree'),
				'id'             => $prefix . 'page_title_custom',
				'desc'           => esc_html__("Enter a custom page title if you'd like.", 'pithree'),
				'type'           => 'text',
				'std'            => '',
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),

			array(
				'name'           => esc_html__('Custom Page Subtitle?', 'pithree'),
				'id'             => $prefix . 'enable_custom_page_subtitle',
				'type'           => 'checkbox',
				'std'            => 0,
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),

			array(
				'name'           => esc_html__('Custom Page Subtitle', 'pithree'),
				'id'             => $prefix . 'page_subtitle_custom',
				'desc'           => esc_html__("Enter a custom page title if you'd like.", 'pithree'),
				'type'           => 'text',
				'std'            => '',
				'required-field' => array(
					array($prefix . 'page_title_enable', '<>', 0),
					array($prefix . 'enable_custom_page_subtitle', '=', 1),
				),
			),

			array(
				'id'             => $prefix . 'page_title_padding',
				'name'           => esc_html__('Padding', 'pithree'),
				'desc'           => esc_html__('Enter a page title padding top value (not include unit)', 'pithree'),
				'type'           => 'padding',
				'allow'          => array(
					'left'  => false,
					'right' => false
				),
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),

			// BACKGROUND OVERLAY
			array(
				'name'  => esc_html__( 'Custom Background Color?', 'pithree' ),
				'id'    => $prefix . 'enable_custom_background_color',
				'type'  => 'checkbox',
				'std'	=> 0,
				'required-field' => array($prefix . 'page_title_enable','<>','0'),
			),
			array(
				'name' => esc_html__('Background Color', 'pithree'),
				'id' => $prefix . 'page_title_bg_color',
				'type'  => 'color',
				'std' => '',
				'required-field' => array(
					array($prefix . 'page_title_enable','<>','0'),
					array($prefix . 'enable_custom_background_color','<>','0'),
				)
			),
			array(
				'name'       => esc_html__( 'Background Color Opacity', 'pithree' ),
				'id'         => $prefix .'page_title_bg_color_opacity',
				'desc'       => esc_html__( 'Set the opacity level of the overlay. This will lighten or darken the image depening on the color selected.', 'pithree' ),
				'clone'      => false,
				'type'       => 'slider',
				'prefix'     => '',
				'js_options' => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array(
					array($prefix . 'page_title_enable','<>','0'),
					array($prefix . 'enable_custom_background_color','<>','0'),
				)
			),

			// BACKGROUND IMAGE
			array(
				'name'           => esc_html__('Custom Background Image?', 'pithree'),
				'id'             => $prefix . 'enable_custom_page_title_bg_image',
				'type'           => 'checkbox',
				'std'            => 0,
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),
			array(
				'id'               => $prefix . 'page_title_bg_image',
				'name'             => esc_html__('Background Image', 'pithree'),
				'desc'             => esc_html__('Background Image for page title.', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'required-field' => array(
					array($prefix . 'page_title_enable','<>','0'),
					array($prefix . 'enable_custom_page_title_bg_image','<>','0'),
				)
			),

			array(
				'name'           => esc_html__('Page Title Parallax', 'pithree'),
				'id'             => $prefix . 'page_title_parallax',
				'desc'           => esc_html__("Enable Page Title Parallax", 'pithree'),
				'type'           => 'button_set',
				'options'        => g5plus_get_toggle(1),
				'std'            => -1,
				'required-field' => array(
					array($prefix . 'page_title_enable','<>','0'),
					array($prefix . 'enable_custom_page_title_bg_image','<>','0'),
				)
			),

			// Breadcrumbs in Page Title
			array(
				'name'           => esc_html__('Breadcrumbs Enable', 'pithree'),
				'id'             => $prefix . 'breadcrumbs_enable',
				'desc'           => esc_html__("Show/Hide Breadcrumbs", 'pithree'),
				'type'           => 'button_set',
				'options'        => g5plus_get_toggle(1),
				'std'            => -1,
				'required-field' => array($prefix . 'page_title_enable', '<>', 0),
			),
		)
	);

	// PAGE FOOTER
	//--------------------------------------------------
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_footer_meta_box',
		'title'      => esc_html__('Page Footer', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name' => esc_html__('General Settings', 'pithree'),
				'id'   => $prefix . 'page_footer_section_1',
				'type' => 'section',
				'std'  => '',
			),
			array(
				'name' => esc_html__('Show/Hide Footer', 'pithree'),
				'id'   => $prefix . 'footer_show_hide',
				'type' => 'checkbox',
				'std'  => '1',
				'desc' => esc_html__('Show/hide footer', 'pithree'),
			),
			array(
				'name'           => esc_html__('Footer Container Layout', 'pithree'),
				'id'             => $prefix . 'footer_container_layout',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'              => esc_html__('Default', 'pithree'),
					'full'            => esc_html__('Full Width', 'pithree'),
					'container-fluid' => esc_html__('Container Fluid', 'pithree'),
					'container'       => esc_html__('Container', 'pithree'),
				),
				'desc'           => esc_html__('Select Footer Wrapper Layout', 'pithree'),
				'required-field' => array($prefix . 'footer_show_hide', '=', '1'),
			),
			array(
				'name'           => esc_html__('Layout', 'pithree'),
				'id'             => $prefix . 'footer_layout',
				'type'           => 'image_set',
				'allowClear'     => true,
				'width'          => '80px',
				'std'            => '',
				'options'        => array(
					'footer-1' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-1.jpg',
					'footer-2' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-2.jpg',
					'footer-3' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-3.jpg',
					'footer-4' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-4.jpg',
					'footer-5' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-5.jpg',
					'footer-6' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-6.jpg',
					'footer-7' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-7.jpg',
					'footer-8' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-8.jpg',
					'footer-9' => G5PLUS_THEME_URL . '/assets/images/theme-options/footer-layout-9.jpg',
				),
				'desc'           => esc_html__('Select Footer Layout (Not set to default).', 'pithree'),
				'required-field' => array($prefix . 'footer_show_hide', '<>', '0'),
			),
			array(
				'name'           => esc_html__('Sidebar 1', 'pithree'),
				'id'             => $prefix . 'footer_sidebar_1',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'footer_show_hide', '=', '1'),
					array($prefix . 'footer_layout', '=', array('footer-1', 'footer-2', 'footer-3', 'footer-4', 'footer-5', 'footer-6', 'footer-7', 'footer-8', 'footer-9'))
				),
			),

			array(
				'name'           => esc_html__('Sidebar 2', 'pithree'),
				'id'             => $prefix . 'footer_sidebar_2',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'footer_show_hide', '=', '1'),
					array($prefix . 'footer_layout', '=', array('footer-1', 'footer-2', 'footer-3', 'footer-4', 'footer-5', 'footer-6', 'footer-7', 'footer-8'))
				),
			),

			array(
				'name'           => esc_html__('Sidebar 3', 'pithree'),
				'id'             => $prefix . 'footer_sidebar_3',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'footer_show_hide', '=', '1'),
					array($prefix . 'footer_layout', '=', array('footer-1', 'footer-2', 'footer-3', 'footer-5', 'footer-8'))
				),
			),

			array(
				'name'           => esc_html__('Sidebar 4', 'pithree'),
				'id'             => $prefix . 'footer_sidebar_4',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'footer_show_hide', '=', '1'),
					array($prefix . 'footer_layout', '=', array('footer-1'))
				),
			),
			array(
				'id'               => $prefix . 'footer_bg_image',
				'name'             => esc_html__('Background Image', 'pithree'),
				'desc'             => esc_html__('Set footer background image', 'pithree'),
				'type'             => 'image_advanced',
				'max_file_uploads' => 1,
				'std'              => '',
				'required-field'   => array($prefix . 'footer_show_hide', '<>', '0'),
			),

			array(
				'name'           => esc_html__('Footer Parallax', 'pithree'),
				'id'             => $prefix . 'footer_parallax',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => 'On',
					'0'  => 'Off'
				),
				'desc'           => esc_html__('Enable Footer Parallax', 'pithree'),
				'required-field' => array($prefix . 'footer_show_hide', '<>', '0'),
			),

			array(
				'name'           => esc_html__('Collapse footer on mobile device', 'pithree'),
				'id'             => $prefix . 'collapse_footer',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1' => esc_html__('Default', 'pithree'),
					'1'  => 'On',
					'0'  => 'Off'
				),
				'desc'           => esc_html__('Enable collapse footer', 'pithree'),
				'required-field' => array($prefix . 'footer_show_hide', '<>', '0'),
			),
			array(
				'name'           => esc_html__('Footer Border Top', 'pithree'),
				'id'             => $prefix . 'footer_border_top',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'               => esc_html__('Default', 'pithree'),
					'none'             => esc_html__('None', 'pithree'),
					'full-border'      => esc_html__('Full Border', 'pithree'),
					'container-border' => esc_html__('Container Border', 'pithree'),
				),
				'required-field' => array($prefix . 'footer_show_hide', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'footer_padding',
				'name'           => esc_html__('Footer padding', 'pithree'),
				'desc'           => esc_html__('Footer padding top. Do not include units (empty to set default)', 'pithree'),
				'type'           => 'padding',
				'allow'          => array(
					'left'  => false,
					'right' => false
				),
				'required-field' => array($prefix . 'footer_show_hide', '<>', '0'),
			),

			//--------------------------------------------------------------------
			array(
				'name' => esc_html__('Bottom Bar Settings', 'pithree'),
				'id'   => $prefix . 'page_footer_section_3',
				'type' => 'section',
				'std'  => '',
			),
			array(
				'name' => esc_html__('Show/Hide Bottom Bar', 'pithree'),
				'id'   => $prefix . 'bottom_bar_visible',
				'type' => 'checkbox',
				'std'  => '1',
				'desc' => esc_html__('Turn ON/OFF Bottom Bar.', 'pithree'),
			),
			array(
				'name'           => esc_html__('Bottom Bar Layout', 'pithree'),
				'id'             => $prefix . 'bottom_bar_layout',
				'type'           => 'image_set',
				'allowClear'     => true,
				'width'          => '80px',
				'std'            => '',
				'options'        => array(
					'bottom-bar-1' => G5PLUS_THEME_URL . '/assets/images/theme-options/bottom-bar-layout-1.jpg',
					'bottom-bar-2' => G5PLUS_THEME_URL . '/assets/images/theme-options/bottom-bar-layout-2.jpg',
					'bottom-bar-3' => G5PLUS_THEME_URL . '/assets/images/theme-options/bottom-bar-layout-3.jpg',
					'bottom-bar-4' => G5PLUS_THEME_URL . '/assets/images/theme-options/bottom-bar-layout-4.jpg',
				),
				'desc'           => esc_html__('Bottom bar layout.', 'pithree'),
				'required-field' => array($prefix . 'bottom_bar_visible', '<>', '0'),
			),

			array(
				'name'           => esc_html__('Bottom Bar Left Sidebar', 'pithree'),
				'id'             => $prefix . 'bottom_bar_left_sidebar',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'bottom_bar_visible', '<>', '0'),
				),
			),

			array(
				'name'           => esc_html__('Bottom Bar Right Sidebar', 'pithree'),
				'id'             => $prefix . 'bottom_bar_right_sidebar',
				'type'           => 'sidebars',
				'placeholder'    => esc_html__('Select Sidebar', 'pithree'),
				'std'            => '',
				'required-field' => array(
					array($prefix . 'bottom_bar_visible', '<>', '0'),
					array($prefix . 'bottom_bar_layout', '<>', 'bottom-bar-4')
				),
			),
			array(
				'name'           => esc_html__('Bottom Bar Border Top', 'pithree'),
				'id'             => $prefix . 'bottom_bar_border_top',
				'type'           => 'button_set',
				'std'            => '-1',
				'options'        => array(
					'-1'               => esc_html__('Default', 'pithree'),
					'none'             => esc_html__('None', 'pithree'),
					'full-border'      => esc_html__('Full Border', 'pithree'),
					'container-border' => esc_html__('Container Border', 'pithree'),
				),
				'required-field' => array($prefix . 'bottom_bar_visible', '<>', '0'),
			),
			array(
				'id'             => $prefix . 'bottom_bar_padding',
				'name'           => esc_html__('Bottom bar padding', 'pithree'),
				'desc'           => esc_html__('Set bottom bar padding. Do not include units (empty to set default)', 'pithree'),
				'type'           => 'padding',
				'allow'          => array(
					'left'  => false,
					'right' => false
				),
				'required-field' => array($prefix . 'bottom_bar_visible', '<>', '0'),
			),
		)
	);

	// Page Color
	//--------------------------------------------------
	$meta_boxes[] = array(
		'id'         => $prefix . 'page_color_meta_box',
		'title'      => esc_html__('Page Colors', 'pithree'),
		'post_types' => array('post', 'page', 'portfolio', 'product'),
		'tab'        => true,
		'fields'     => array(
			array(
				'name'   => esc_html__('Top Drawer Customize?', 'pithree'),
				'id'     => $prefix . 'enable_top_drawer_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Top drawer background color', 'pithree'),
				'id'             => $prefix . 'top_drawer_bg_color',
				'type'           => 'color',
				'std'            => '#ffa60a',
				'required-field' => array($prefix . 'enable_top_drawer_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Top drawer text color', 'pithree'),
				'id'             => $prefix . 'top_drawer_text_color',
				'type'           => 'color',
				'std'            => '#2c3e50',
				'required-field' => array($prefix . 'enable_top_drawer_color', '=', '1'),
			),

			//------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Header Customize?', 'pithree'),
				'id'     => $prefix . 'enable_header_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Header background color', 'pithree'),
				'id'             => $prefix . 'header_bg_color',
				'type'           => 'color',
				'std'            => '#fff',
				'required-field' => array($prefix . 'enable_header_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Header overlay', 'pithree'),
				'id'             => $prefix . 'header_overlay',
				'desc'           => esc_html__('Set the opacity level of the header background color (apply for header float)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '0',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array($prefix . 'enable_header_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Header text color', 'pithree'),
				'id'             => $prefix . 'header_text_color',
				'type'           => 'color',
				'std'            => '#8a8a8a',
				'required-field' => array($prefix . 'enable_header_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Header border color', 'pithree'),
				'id'             => $prefix . 'header_border_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_header_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Header above border color', 'pithree'),
				'id'             => $prefix . 'header_above_border_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_header_color', '=', '1'),
			),

			//------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Top Bar Customize?', 'pithree'),
				'id'     => $prefix . 'enable_top_bar_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Top bar background color', 'pithree'),
				'id'             => $prefix . 'top_bar_bg_color',
				'type'           => 'color',
				'std'            => '#f1f1f1',
				'required-field' => array($prefix . 'enable_top_bar_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Top bar overlay', 'pithree'),
				'id'             => $prefix . 'top_bar_overlay',
				'desc'           => esc_html__('Set the opacity level of the top bar background color (apply for header float)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '0',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array($prefix . 'enable_top_bar_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Top bar text color', 'pithree'),
				'id'             => $prefix . 'top_bar_text_color',
				'type'           => 'color',
				'std'            => '#2c3e50',
				'required-field' => array($prefix . 'enable_top_bar_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Top bar border color', 'pithree'),
				'id'             => $prefix . 'top_bar_border_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_top_bar_color', '=', '1'),
			),

			//------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Navigation Customize?', 'pithree'),
				'id'     => $prefix . 'enable_navigation_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Navigation background color', 'pithree'),
				'id'             => $prefix . 'navigation_bg_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_navigation_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Navigation overlay', 'pithree'),
				'id'             => $prefix . 'navigation_overlay',
				'desc'           => esc_html__('Set the opacity level of the top bar background color (apply for header float)', 'pithree'),
				'clone'          => false,
				'type'           => 'slider',
				'prefix'         => '',
				'std'            => '0',
				'js_options'     => array(
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				),
				'required-field' => array($prefix . 'enable_navigation_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Navigation text color', 'pithree'),
				'id'             => $prefix . 'navigation_text_color',
				'type'           => 'color',
				'std'            => '#8a8a8a',
				'required-field' => array($prefix . 'enable_navigation_color', '=', '1'),
			),

			//------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Footer Customize?', 'pithree'),
				'id'     => $prefix . 'enable_footer_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Footer background color', 'pithree'),
				'id'             => $prefix . 'footer_bg_color',
				'type'           => 'color',
				'std'            => '#1b2c3e',
				'required-field' => array($prefix . 'enable_footer_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Footer text color', 'pithree'),
				'id'             => $prefix . 'footer_text_color',
				'type'           => 'color',
				'std'            => '#979da4',
				'required-field' => array($prefix . 'enable_footer_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Footer widget title color', 'pithree'),
				'id'             => $prefix . 'footer_widget_title_color',
				'type'           => 'color',
				'std'            => '#fff',
				'required-field' => array($prefix . 'enable_footer_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Footer border color', 'pithree'),
				'id'             => $prefix . 'footer_border_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_footer_color', '=', '1'),
			),

			//------------------------------------------------------------------------
			array(
				'name'   => esc_html__('Bottom Bar Customize?', 'pithree'),
				'id'     => $prefix . 'enable_bottom_bar_color',
				'type'   => 'section',
				'std'    => '0',
				'switch' => true,
			),
			array(
				'name'           => esc_html__('Bottom bar background color', 'pithree'),
				'id'             => $prefix . 'bottom_bar_bg_color',
				'type'           => 'color',
				'std'            => '#172737',
				'required-field' => array($prefix . 'enable_bottom_bar_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Bottom bar text color', 'pithree'),
				'id'             => $prefix . 'bottom_bar_text_color',
				'type'           => 'color',
				'std'            => '#979da4',
				'required-field' => array($prefix . 'enable_bottom_bar_color', '=', '1'),
			),
			array(
				'name'           => esc_html__('Bottom bar border color', 'pithree'),
				'id'             => $prefix . 'bottom_bar_border_color',
				'type'           => 'color',
				'std'            => '#e0e0e0',
				'required-field' => array($prefix . 'enable_bottom_bar_color', '=', '1'),
			),
		)
	);

	// Make sure there's no errors when the plugin is deactivated or during upgrade
	if (class_exists('RW_Meta_Box')) {
		foreach ($meta_boxes as $meta_box) {
			new RW_Meta_Box($meta_box);
		}
	}
}

// Hook to 'admin_init' to make sure the meta box class is loaded before
// (in case using the meta box class in another plugin)
// This is also helpful for some conditionals like checking page template, categories, etc.
add_action('admin_init', 'g5plus_register_meta_boxes');
