<?php

/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'Redux_Framework_options_config' ) ) {

    class Redux_Framework_options_config {

        public $args = array();
        public $sections = array();
        public $theme;
        public $ReduxFramework;

        public function __construct() {
            if ( ! class_exists( 'ReduxFramework' ) ) {
                return;
            }
            $this->initSettings();
        }

        public function initSettings() {
            // Set the default arguments
            $this->setArguments();

            // Set a few help tabs so you can see how it's done
            $this->setHelpTabs();

            // Create the sections and fields
            $this->setSections();

            if ( ! isset( $this->args['opt_name'] ) ) { // No errors please
                return;
            }
            $this->ReduxFramework = new ReduxFramework( $this->sections, $this->args );
        }

	    private function get_section_start($id,$title) {
		    return array(
			    'id' => $id . '_start',
			    'type' => 'section',
			    'title' => $title,
			    'indent' => true
		    );
	    }

	    private function get_section_end($id) {
		    return array(
			    'id' => $id . '_end',
			    'type' => 'section',
			    'indent' => false
		    );
	    }

		private function get_pages(){
			$args = array(
				'sort_order' => 'asc',
				'sort_column' => 'post_title',
				'hierarchical' => 1,
				'offset' => 0,
				'post_type' => 'page',
				'post_status' => 'publish'
			);
			$pages = get_pages($args);
			$list_page = array();
			foreach ( $pages as $page ) {
				$list_page[$page->post_name] = $page->post_title;
			}
			return $list_page;
		}
	    private function get_page_layout($id,$required = array() , $default = 'container') {
		    return array(
			        'id' => $id,
				    'type' => 'button_set',
				    'title' => esc_html__('Layout', 'pithree'),
				    'subtitle' => esc_html__('Select Page Layout', 'pithree'),
				    'desc' => '',
				    'options' => g5plus_get_page_layout(),
				    'default' => $default,
			        'required'  => $required,
			    );
	    }

	    private function get_sidebar_layout($id,$required = array(),$default = 'left') {
		    return  array(
			    'id' => $id,
			    'type' => 'image_select',
			    'title' => esc_html__('Sidebar Layout', 'pithree'),
			    'subtitle' => esc_html__('Set Sidebar Layout', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_sidebar_layout(),
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_sidebar_width($id,$required = array() , $default = 'small') {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Sidebar Width', 'pithree'),
			    'subtitle' => esc_html__('Set Sidebar width', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_sidebar_width(),
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_sidebar_mobile_enable($id,$required = array(),$default = 1) {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Sidebar Mobile', 'pithree'),
			    'subtitle' => esc_html__('Turn Off this option if you want to disable sidebar on mobile', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_toggle(),
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_sidebar($id,$required = array() , $default = 'main-sidebar') {
		    return array(
			    'id' => $id,
			    'type' => 'select',
			    'title' => esc_html__('Sidebar', 'pithree'),
			    'subtitle' => '',
			    'data'      => 'sidebars',
			    'desc' => '',
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_content_padding($id,$required = array(), $default = array('padding-top'  => '70px','padding-bottom'  => '70px','units'=>'px')) {
		    return array(
			    'id'             => $id,
			    'type'           => 'spacing',
			    'mode'           => 'padding',
			    'units'          => 'px',
			    'units_extended' => 'false',
			    'title'          => esc_html__('Content Padding', 'pithree'),
			    'subtitle'       => esc_html__('Set content top/bottom padding.', 'pithree'),
			    'desc'           => '',
			    'left'          => false,
			    'right'          => false,
			    'default'       => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_enable($id,$required = array(), $default = 1) {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Page Title Enable', 'pithree'),
			    'subtitle' => esc_html__('Enable/Disable Page Title', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_toggle(),
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_layout($id,$required = array(),$default = 'center') {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Page Title Layout', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_page_title_layout(),
			    'default' => $default,
			    'required'  => $required
		    );
	    }

		private function get_page_title_title_color($id,$required = array(), $default = '#000'){
			return array(
				'id' => $id,
				'type' => 'color',
				'title' => esc_html__('Title Color','pithree'),
				'default' => $default,
				'required' => $required,
			);
		}

	    private function get_page_sub_title($id,$required = array()) {
		    return array(
			    'id' => $id,
			    'type' => 'text',
			    'title' => esc_html__('Page Sub Title', 'pithree'),
			    'subtitle' => '',
			    'desc' => '',
			    'default' => '',
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_padding($id,$required = array(),$default = array('padding-top' => '80px','padding-bottom' => '80px','units' => 'px')) {
		    return array(
			    'id'             => $id,
			    'type'           => 'spacing',
			    'mode'           => 'padding',
			    'units'          => 'px',
			    'units_extended' => 'false',
			    'title'          => esc_html__('Padding', 'pithree'),
			    'subtitle'       => esc_html__('Set page title top/bottom padding.', 'pithree'),
			    'desc'           => '',
			    'left'          => false,
			    'right'          => false,
			    'default'            => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_background_image($id,$required = array(),$default = array()) {
		    return array(
			    'id' => $id,
			    'type' => 'media',
			    'url'=> true,
			    'title' => esc_html__('Background Image', 'pithree'),
			    'subtitle' => esc_html__('Upload page title background.', 'pithree'),
			    'desc' => '',
			    'default' => array(
					'url' => $default,
				),
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_background_overlay($id,$required = array(),$default = array(
		    'color'     => '#fff',
		    'alpha'     => 0.85,
		    'rgba'     => 'rgba(255,255,255,0.85)'
	    )) {
		    return array(
			    'id' => $id,
			    'type' => 'color_rgba',
			    'url'=> true,
			    'title' => esc_html__('Background Overlay', 'pithree'),
			    'subtitle' => esc_html__('Upload page title background color overlay.', 'pithree'),
			    'desc' => '',
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_page_title_parallax($id,$required = array(),$default = 1) {
		    return array(
			    'id'       => $id,
			    'type'     => 'button_set',
			    'title'    => esc_html__( 'Page Title Parallax', 'pithree' ),
			    'subtitle' => esc_html__( 'Enable Page Title Parallax', 'pithree' ),
			    'desc'     => '',
			    'options'  => g5plus_get_toggle(),
			    'default'  => $default,
			    'required'  => $required,
		    );
	    }

	    private function get_breadcrumb_enable($id,$required = array(),$default = 1) {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Breadcrumbs Enable', 'pithree'),
			    'subtitle' => esc_html__('Enable/Disable Breadcrumbs In Pages Title', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_toggle(),
			    'default' => $default,
			    'required'  => $required
		    );
	    }

	    private function get_theme_color_enable($id,$required = array(), $default = 0) {
		    return array(
			    'id' => $id,
			    'type' => 'button_set',
			    'title' => esc_html__('Customize Color', 'pithree'),
			    'subtitle' => esc_html__('Select "Customize" if you want to change default theme color', 'pithree'),
			    'desc' => '',
			    'options' => g5plus_get_toggle_color(),
			    'default' => $default,
			    'required'  => $required,
		    );
	    }

        public function setSections() {
			$page_title_bg = G5PLUS_THEME_URL . 'assets/images/bg-page-title.jpg';

            $fonts =array(
                            "Arial, Helvetica, sans-serif"                         => "Arial, Helvetica, sans-serif",
                            "'Arial Black', Gadget, sans-serif"                    => "'Arial Black', Gadget, sans-serif",
                            "'Bookman Old Style', serif"                           => "'Bookman Old Style', serif",
                            "'Comic Sans MS', cursive"                             => "'Comic Sans MS', cursive",
                            "Courier, monospace"                                   => "Courier, monospace",
                            "Garamond, serif"                                      => "Garamond, serif",
                            "Georgia, serif"                                       => "Georgia, serif",
                            "Impact, Charcoal, sans-serif"                         => "Impact, Charcoal, sans-serif",
                            "'Lucida Console', Monaco, monospace"                  => "'Lucida Console', Monaco, monospace",
                            "'Lucida Sans Unicode', 'Lucida Grande', sans-serif"   => "'Lucida Sans Unicode', 'Lucida Grande', sans-serif",
                            "'MS Sans Serif', Geneva, sans-serif"                  => "'MS Sans Serif', Geneva, sans-serif",
                            "'MS Serif', 'New York', sans-serif"                   => "'MS Serif', 'New York', sans-serif",
                            "'Palatino Linotype', 'Book Antiqua', Palatino, serif" => "'Palatino Linotype', 'Book Antiqua', Palatino, serif",
                            "Tahoma,Geneva, sans-serif"                            => "Tahoma, Geneva, sans-serif",
                            "'Times New Roman', Times,serif"                       => "'Times New Roman', Times, serif",
                            "'Trebuchet MS', Helvetica, sans-serif"                => "'Trebuchet MS', Helvetica, sans-serif",
                            "Verdana, Geneva, sans-serif"                          => "Verdana, Geneva, sans-serif",
                        );

            // General Setting
            $this->sections[] = array(
                'title'  => esc_html__( 'General Setting', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-wrench',
                'fields' => array(
	                array(
		                'id' => 'page_comment_enable',
		                'type' => 'button_set',
		                'title' => esc_html__('Page Comment', 'pithree'),
		                'subtitle' => esc_html__('Enable/Disable page comment', 'pithree'),
		                'desc' => '',
		                'options' => g5plus_get_toggle(),
		                'default' => 1
	                ),
                    array(
                        'id' => 'smooth_scroll',
                        'type' => 'button_set',
                        'title' => esc_html__('Smooth Scroll', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Smooth Scroll', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),

                    array(
                        'id' => 'custom_scroll',
                        'type' => 'button_set',
                        'title' => esc_html__('Custom Scroll', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Custom Scroll', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),

                    array(
                        'id'        => 'custom_scroll_width',
                        'type'      => 'text',
                        'title'     => esc_html__('Custom Scroll Width', 'pithree'),
                        'subtitle'  => esc_html__('This must be numeric (no px) or empty.', 'pithree'),
                        'validate'  => 'numeric',
                        'default'   => '10',
                        'required'  => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id'       => 'custom_scroll_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Custom Scroll Color', 'pithree'),
                        'subtitle' => esc_html__('Set Custom Scroll Color', 'pithree'),
                        'default'  => '#19394B',
                        'validate' => 'color',
                        'required'  => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id'       => 'custom_scroll_thumb_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Custom Scroll Thumb Color', 'pithree'),
                        'subtitle' => esc_html__('Set Custom Scroll Thumb Color', 'pithree'),
                        'default'  => '#e8aa00',
                        'validate' => 'color',
                        'required'  => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id' => 'back_to_top',
                        'type' => 'button_set',
                        'title' => esc_html__('Back To Top', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Back to top button', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 1
                    ),

	                array(
		                'id' => 'enable_rtl_mode',
		                'type' => 'button_set',
		                'title' => esc_html__('Enable RTL mode', 'pithree'),
		                'subtitle' => esc_html__('Enable/Disable RTL mode', 'pithree'),
		                'desc' => '',
		                'options' => g5plus_get_toggle(),
		                'default' => 0
	                ),

	                array(
                        'id' => 'social_meta_enable',
                        'type' => 'button_set',
                        'title' => esc_html__('Enable Social Meta Tags', 'pithree'),
                        'subtitle' => esc_html__('Enable the social meta head tag output.', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),

                    array(
                        'id' => 'twitter_author_username',
                        'type' => 'text',
                        'title' => esc_html__('Twitter Publisher Username', 'pithree'),
                        'subtitle' => esc_html__( 'Enter your twitter username here, to be used for the Twitter Card date. Ensure that you do not include the @ symbol.','pithree'),
                        'desc' => '',
                        'default' => "",
                        'required'  => array('enable_social_meta', '=', array('1')),
                    ),
                    array(
                        'id' => 'googleplus_author',
                        'type' => 'text',
                        'title' => esc_html__('Google+ Username', 'pithree'),
                        'subtitle' => esc_html__('Enter your Google+ username here, to be used for the authorship meta.','pithree'),
                        'desc' => '',
                        'default' => "",
                        'required'  => array('enable_social_meta', '=', array('1')),
                    ),


                    array(
                        'id' => 'general_divide_2',
                        'type' => 'divide'
                    ),

	                array(
		                'id' => 'shopping_cart_button',
		                'type' => 'checkbox',
		                'title' => esc_html__('Shopping Mini Cart Button', 'pithree'),
		                'subtitle' => esc_html__('Select shopping mini cart button', 'pithree'),
		                'options' => array(
			                'view-cart' => esc_html__('View Cart','pithree'),
			                'checkout' => esc_html__('Checkout','pithree'),
		                ),
		                'default' => array(
			                'view-cart' => '1',
			                'checkout' => '1',
		                ),
	                ),
	                array(
		                'id'       => 'shopping_cart_scheme',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Shopping mini cart scheme', 'pithree' ),
		                'subtitle' => esc_html__( 'Choose shopping mini cart scheme', 'pithree' ),
		                'desc'     => '',
		                'options'  => array(
			                'light'     => esc_html__('Light','pithree'),
			                'dark'      => esc_html__('Dark','pithree')
		                ),
		                'default'  => 'light'
	                ),
	                array(
		                'id' => 'search_popup_type',
		                'type' => 'button_set',
		                'title' => esc_html__('Search Popup Type', 'pithree'),
		                'subtitle' => esc_html__('Select search popup type.', 'pithree'),
		                'desc' => '',
		                'options' => array('standard' => esc_html__('Standard','pithree'),'ajax' => esc_html__('Ajax Search','pithree')),
		                'default' => 'standard'
	                ),
	                array(
		                'id' => 'search_popup_post_type',
		                'type' => 'checkbox',
		                'title' => esc_html__('Post type for Ajax Search', 'pithree'),
		                'subtitle' => esc_html__('Select post type for ajax search', 'pithree'),
		                'options' => array(
			                'post' => 'Post',
			                'page' => 'Page',
			                'product' => 'Product',
			                'portfolio' => 'Portfolio',
			                'services' => 'Our Services',
		                ),
		                'default' => array(
			                'post'      => '1',
			                'page'      => '0',
			                'product'   => '1',
			                'portfolio' => '1',
			                'services'   => '1',
		                ),
		                'required' => array('search_popup_type','=','ajax'),
	                ),

	                array(
		                'id'        => 'search_popup_result_amount',
		                'type'      => 'text',
		                'title'     => esc_html__('Amount Of Search Result', 'pithree'),
		                'subtitle'  => esc_html__('This must be numeric (no px) or empty (default: 8).', 'pithree'),
		                'desc'      => esc_html__('Set mount of Search Result', 'pithree'),
		                'validate'  => 'numeric',
		                'default'   => '8',
		                'required' => array('search_popup_type','=','ajax'),
	                ),

	                array(
		                'id' => 'general_divide_3',
		                'type' => 'divide'
	                ),
	                array(
		                'id' => 'menu_transition',
		                'type' => 'button_set',
		                'title' => esc_html__('Menu transition', 'pithree'),
		                'subtitle' => esc_html__('Select menu transition', 'pithree'),
		                'desc' => '',
		                'options' => array(
			                'none'                  => esc_html__('None','pithree'),
			                'x-animate-slide-up'    => esc_html__('Slide Up','pithree'),
			                'x-animate-slide-down'  => esc_html__('Slide Down','pithree'),
			                'x-animate-slide-left'  => esc_html__('Slide Left','pithree'),
			                'x-animate-slide-right' => esc_html__('Slide Right','pithree'),
			                'x-animate-sign-flip'   => esc_html__('Sign Flip','pithree'),
		                ),
		                'default' => 'x-animate-sign-flip'
	                ),
                )
            );

            $this->sections[] = array(
                'title' => esc_html__('Maintenance Mode', 'pithree'),
                'desc' => '',
                'subsection' => true,
                'icon' => 'el-icon-eye-close',
                'fields' => array(
                    array(
                        'id' => 'enable_maintenance',
                        'type' => 'button_set',
                        'title' => esc_html__('Enable Maintenance', 'pithree'),
                        'subtitle' => esc_html__('Enable the themes maintenance mode.', 'pithree'),
                        'desc' => '',
                        'options' => array('2' => 'On (Custom Page)', '1' => 'On (Standard)','0' => 'Off',),
                        'default' => '0'
                    ),
                    array(
                        'id' => 'maintenance_mode_page',
                        'type' => 'select',
                        'data' => 'pages',
                        'required'  => array('enable_maintenance', '=', '2'),
                        'title' => esc_html__('Custom Maintenance Mode Page', 'pithree'),
                        'subtitle' => esc_html__('Select the page that is your maintenace page, if you would like to show a custom page instead of the standard WordPress message. You should use the Holding Page template for this page.', 'pithree'),
                        'desc' => '',
                        'default' => '',
                        'args' => array()
                    ),
                ),
            );


            // Performance Options
            $this->sections[] = array(
                'title'  => esc_html__( 'Performance', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-fire',
                'subsection' => true,
                'fields' => array(
                    array(
                        'id' => 'enable_minifile_js',
                        'type' => 'button_set',
                        'title' => esc_html__('Enable Mini File JS', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Mini File JS', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),
                    array(
                        'id' => 'enable_minifile_css',
                        'type' => 'button_set',
                        'title' => esc_html__('Enable Mini File CSS', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Mini File CSS', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),
                )
            );

            // Page Transition
            $this->sections[] = array(
                'title'  => esc_html__( 'Page Transition', 'pithree'),
                'desc'   => '',
                'icon'   => 'el el-dashboard',
                'subsection' => true,
                'fields' => array(

                    array(
                        'id' => 'page_transition',
                        'type' => 'button_set',
                        'title' => esc_html__('Page Transition', 'pithree'),
                        'subtitle' => esc_html__('Enable/Disable Page Transition', 'pithree'),
                        'desc' => '',
                        'options' => g5plus_get_toggle(),
                        'default' => 0
                    ),

                    //Loading Animation
                    array(
                        'id' => 'loading_animation',
                        'type' => 'select',
                        'title' => esc_html__('Loading Animation', 'pithree'),
                        'subtitle' => esc_html__('Choose type of preload animation', 'pithree'),
                        'desc' => '',
                        'options' => array(
                            'none' => esc_html__('No animation','pithree'),
                            'cube' => esc_html__('Cube','pithree'),
                            'double-bounce' => esc_html__('Double bounce','pithree'),
                            'wave' => esc_html__('Wave','pithree'),
                            'pulse' => esc_html__('Pulse','pithree'),
                            'chasing-dots' => esc_html__('Chasing dots','pithree'),
                            'three-bounce' => esc_html__('Three bounce','pithree'),
                            'circle' => esc_html__('Circle','pithree'),
                            'fading-circle' => esc_html__('Fading circle','pithree'),
                            'folding-cube' => esc_html__('Folding cube','pithree'),
                        ),
                        'default' => 'none'
                    ),

                    array(
                        'id' => 'loading_logo',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Logo Loading', 'pithree'),
                        'subtitle' => esc_html__('Upload logo loading.', 'pithree'),
                        'desc' => '',
                        'required'  => array('loading_animation', 'not_empty_and', array('none')),
                    ),

                    array(
                        'id'       => 'loading_animation_bg_color',
                        'type'     => 'color_rgba',
                        'title'    => esc_html__('Loading Background Color', 'pithree' ),
                        'subtitle' => esc_html__( 'Set loading background color.', 'pithree' ),
                        'default'   => array(
                            'color'     => '#ffffff',
                            'alpha'     => 1
                        ),
                        'output' => array('background-color' => '.site-loading'),
                        'validate' => 'colorrgba',
                        'required'  => array('loading_animation', 'not_empty_and', array('none')),
                    ),

                    //Spinner Color
                    array(
                        'id'       => 'spinner_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Spinner color', 'pithree'),
                        'subtitle' => esc_html__('Pick a spinner color', 'pithree'),
                        'default'  => '',
                        'validate' => 'color',
                        'output' => array('background-color' => '.sk-spinner-pulse,.sk-rotating-plane,.sk-double-bounce .sk-child,.sk-wave .sk-rect,.sk-chasing-dots .sk-child,.sk-three-bounce .sk-child,.sk-circle .sk-child:before,.sk-fading-circle .sk-circle:before,.sk-folding-cube .sk-cube:before'),
                        'required'  => array('loading_animation', 'not_empty_and', array('none')),
                    ),
                )
            );

            // Custom Favicon
            $this->sections[] = array(
                'title'  => esc_html__( 'Custom Favicon', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-eye-open',
                'subsection' => true,
                'fields' => array(
                    array(
                        'id' => 'custom_favicon',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Custom favicon', 'pithree'),
                        'subtitle' => esc_html__('Upload a 16px x 16px Png/Gif/ico image that will represent your website favicon', 'pithree'),
                        'desc' => ''
                    ),
                    array(
                        'id' => 'custom_ios_title',
                        'type' => 'text',
                        'title' => esc_html__('Custom iOS Bookmark Title', 'pithree'),
                        'subtitle' => esc_html__('Enter a custom title for your site for when it is added as an iOS bookmark.', 'pithree'),
                        'desc' => '',
                        'default' => ''
                    ),
                    array(
                        'id' => 'custom_ios_icon57',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Custom iOS 57x57', 'pithree'),
                        'subtitle' => esc_html__('Upload a 57px x 57px Png image that will be your website bookmark on non-retina iOS devices.', 'pithree'),
                        'desc' => ''
                    ),
                    array(
                        'id' => 'custom_ios_icon72',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Custom iOS 72x72', 'pithree'),
                        'subtitle' => esc_html__('Upload a 72px x 72px Png image that will be your website bookmark on non-retina iOS devices.', 'pithree'),
                        'desc' => ''
                    ),
                    array(
                        'id' => 'custom_ios_icon114',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Custom iOS 114x114', 'pithree'),
                        'subtitle' => esc_html__('Upload a 114px x 114px Png image that will be your website bookmark on retina iOS devices.', 'pithree'),
                        'desc' => ''
                    ),
                    array(
                        'id' => 'custom_ios_icon144',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Custom iOS 144x144', 'pithree'),
                        'subtitle' => esc_html__('Upload a 144px x 144px Png image that will be your website bookmark on retina iOS devices.', 'pithree'),
                        'desc' => ''
                    ),
                )
            );


            // 404
            $this->sections[] = array(
                'title'  => esc_html__( '404 Setting', 'pithree' ),
                'desc'   => '',
                'subsection' => true,
                'icon'   => 'el el-error',
                'fields' => array(

                    array(
                        'id'        => 'title_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Title 404', 'pithree'),
                        'default'   => '404',
                    ),
                    array(
                        'id'        => 'subtitle_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Subtitle 404', 'pithree'),
                        'default'   => 'Oops! Page not found',
                    ),
					array(
						'id'        => 'description_404',
						'type'      => 'textarea',
						'title'     => esc_html__('Description 404', 'pithree'),
						'default'   => 'Sorry, but the page you are looking for is not found. Please, make sure you have typed the current URL.',
					),
                    array(
                        'id'        => 'go_back_url_404',
                        'type'      => 'text',
                        'title'     => esc_html__('Go back link', 'pithree'),
                        'default'   => '',
                    ),
                )
            );

	        // Layout
	        $this->sections[] = array(
		        'title' => esc_html__('Layout Options','pithree'),
		        'icon' => 'el el-website',
		        'fields' => array(
			        // General
			        array(
				        'id' => 'layout_style',
				        'type' => 'image_select',
				        'title' => esc_html__('Layout Style', 'pithree'),
				        'subtitle' => esc_html__('Select the layout style', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_layout_style(),
				        'default' => 'wide'
			        ),
			        array(
				        'id' => 'body_background_mode',
				        'type' => 'button_set',
				        'title' => esc_html__('Body Background Mode', 'pithree'),
				        'subtitle' => esc_html__('Chose Background Mode', 'pithree'),
				        'desc' => '',
				        'options' => array(
					        'background' => esc_html__('Background','pithree'),
					        'pattern' => esc_html__('Pattern','pithree')
				        ),
				        'default' => 'background',
			        ),
			        array(
				        'id'       => 'body_background',
				        'type'     => 'background',
				        'output'   => array( 'body' ),
				        'title'    => esc_html__( 'Body Background', 'pithree' ),
				        'subtitle' => esc_html__( 'Body background (Apply for Boxed layout style).', 'pithree' ),
				        'default'  => array(
					        'background-color' => '',
					        'background-repeat' => 'no-repeat',
					        'background-position' => 'center center',
					        'background-attachment' => 'fixed',
					        'background-size' => 'cover'
				        ),
				        'required'  => array(
					        array('body_background_mode', '=', array('background'))
				        ),
			        ),
			        array(
				        'id' => 'body_background_pattern',
				        'type' => 'image_select',
				        'title' => esc_html__('Background Pattern', 'pithree'),
				        'subtitle' => esc_html__('Body background pattern(Apply for Boxed layout style)', 'pithree'),
				        'desc' => '',
				        'height' => '40px',
				        'options' => array(
					        'pattern-1.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-1.png'),
					        'pattern-2.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-2.png'),
					        'pattern-3.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-3.png'),
					        'pattern-4.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-4.png'),
					        'pattern-5.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-5.png'),
					        'pattern-6.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-6.png'),
					        'pattern-7.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-7.png'),
					        'pattern-8.png' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/pattern-8.png'),
				        ),
				        'default' => 'pattern-1.png',
				        'required'  => array(
					        array('body_background_mode', '=', array('pattern'))
				        ) ,
			        ),
			        array(
				        'id' => 'widget_layout',
				        'type' => 'select',
				        'title' => esc_html__('Widget Layout','pithree'),
				        'options' => g5plus_get_widget_layout(),
				        'default' => 'widget-classic'
			        ),
			        // Pages Layout
			        $this->get_section_start('page_layout',esc_html__('Pages','pithree')),
			        array(
				        'id' => 'custom_page_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on pages', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('page_layout',array('custom_page_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('page_sidebar_layout', array('custom_page_layout_enable', '=', 1)),
			        $this->get_sidebar('page_sidebar',array(
				        array('custom_page_layout_enable', '=', 1),
				        array('page_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('page_sidebar_width',array(
				        array('custom_page_layout_enable', '=', 1),
				        array('page_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('page_sidebar_mobile_enable',array(
				        array('custom_page_layout_enable', '=', 1),
				        array('page_sidebar_layout', '=', array('left','right'))
			        )),

			        $this->get_content_padding('page_content_padding',array('custom_page_layout_enable', '=', 1)),
			        // Blog Layout
			        $this->get_section_start('blog_layout',esc_html__('Blog','pithree')),
			        array(
				        'id' => 'custom_blog_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('blog_layout',array('custom_blog_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('blog_sidebar_layout', array('custom_blog_layout_enable', '=', 1)),
			        $this->get_sidebar('blog_sidebar',array(
				        array('custom_blog_layout_enable', '=', 1),
				        array('blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('blog_sidebar_width',array(
				        array('custom_blog_layout_enable', '=', 1),
				        array('blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('blog_sidebar_mobile_enable',array(
				        array('custom_blog_layout_enable', '=', 1),
				        array('blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('blog_content_padding',array('custom_blog_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
			        // Single Blog Layout
			        $this->get_section_start('single_blog_layout',esc_html__('Single Blog','pithree')),
			        array(
				        'id' => 'custom_single_blog_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('single_blog_layout',array('custom_single_blog_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('single_blog_sidebar_layout', array('custom_single_blog_layout_enable', '=', 1)),
			        $this->get_sidebar('single_blog_sidebar',array(
				        array('custom_single_blog_layout_enable', '=', 1),
				        array('single_blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('single_blog_sidebar_width',array(
				        array('custom_single_blog_layout_enable', '=', 1),
				        array('single_blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('single_blog_sidebar_mobile_enable',array(
				        array('custom_single_blog_layout_enable', '=', 1),
				        array('single_blog_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('single_blog_content_padding',array('custom_single_blog_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
			        // Shop Layout
			        $this->get_section_start('archive_product_layout',esc_html__('Archive Product','pithree')),
			        array(
				        'id' => 'custom_archive_product_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on archive product', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('archive_product_layout',array('custom_archive_product_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('archive_product_sidebar_layout', array('custom_archive_product_layout_enable', '=', 1),'none'),
			        $this->get_sidebar('archive_product_sidebar',array(
				        array('custom_archive_product_layout_enable', '=', 1),
				        array('archive_product_sidebar_layout', '=', array('left','right'))
			        ),'woocommerce'),
			        $this->get_sidebar_width('archive_product_sidebar_width',array(
				        array('custom_archive_product_layout_enable', '=', 1),
				        array('archive_product_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('archive_product_sidebar_mobile_enable',array(
				        array('custom_archive_product_layout_enable', '=', 1),
				        array('archive_product_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('archive_product_content_padding',array('custom_archive_product_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
			        // Single Product Layout
			        $this->get_section_start('single_product_layout',esc_html__('Single Product','pithree')),
			        array(
				        'id' => 'custom_single_product_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on single product', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('single_product_layout',array('custom_single_product_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('single_product_sidebar_layout', array('custom_single_product_layout_enable', '=', 1),'none'),
			        $this->get_sidebar('single_product_sidebar',array(
				        array('custom_single_product_layout_enable', '=', 1),
				        array('single_product_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('single_product_sidebar_width',array(
				        array('custom_single_product_layout_enable', '=', 1),
				        array('single_product_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('single_product_sidebar_mobile_enable',array(
				        array('custom_single_product_layout_enable', '=', 1),
				        array('single_product_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('single_product_content_padding',array('custom_single_product_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
			        // Archive Portfolio Layout
			        $this->get_section_start('archive_portfolio_layout',esc_html__('Archive Portfolio','pithree')),
			        array(
				        'id' => 'custom_archive_portfolio_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout archive portfolio', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('archive_portfolio_layout',array('custom_archive_portfolio_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('archive_portfolio_sidebar_layout', array('custom_archive_portfolio_layout_enable', '=', 1)),
			        $this->get_sidebar('archive_portfolio_sidebar',array(
				        array('custom_archive_portfolio_layout_enable', '=', 1),
				        array('archive_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('archive_portfolio_sidebar_width',array(
				        array('custom_archive_portfolio_layout_enable', '=', 1),
				        array('archive_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('archive_portfolio_sidebar_mobile_enable',array(
				        array('custom_archive_portfolio_layout_enable', '=', 1),
				        array('archive_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('archive_portfolio_content_padding',array('custom_archive_portfolio_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
			        // Single Portfolio Layout
			        $this->get_section_start('single_portfolio_layout',esc_html__('Single Portfolio','pithree')),
			        array(
				        'id' => 'custom_single_portfolio_layout_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Layout', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on single portfolio', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_layout('single_portfolio_layout',array('custom_single_portfolio_layout_enable', '=', 1)),
			        $this->get_sidebar_layout('single_portfolio_sidebar_layout', array('custom_single_portfolio_layout_enable', '=', 1)),
			        $this->get_sidebar('single_portfolio_sidebar',array(
				        array('custom_single_portfolio_layout_enable', '=', 1),
				        array('single_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_width('single_portfolio_sidebar_width',array(
				        array('custom_single_portfolio_layout_enable', '=', 1),
				        array('single_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_sidebar_mobile_enable('single_portfolio_sidebar_mobile_enable',array(
				        array('custom_single_portfolio_layout_enable', '=', 1),
				        array('single_portfolio_sidebar_layout', '=', array('left','right'))
			        )),
			        $this->get_content_padding('single_portfolio_content_padding',array('custom_single_portfolio_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
					// Archive Services Layout
					$this->get_section_start('archive_services_layout',esc_html__('Archive Services','pithree')),
					array(
						'id' => 'custom_archive_services_layout_enable',
						'type' => 'button_set',
						'title' => esc_html__('Custom Layout', 'pithree'),
						'subtitle' => esc_html__('Turn on this option if you want to enable custom layout archive services', 'pithree'),
						'desc' => '',
						'options' => g5plus_get_toggle(),
						'default' => 0
					),
					$this->get_page_layout('archive_services_layout',array('custom_archive_services_layout_enable', '=', 1)),
					$this->get_sidebar_layout('archive_services_sidebar_layout', array('custom_archive_services_layout_enable', '=', 1)),
					$this->get_sidebar('archive_services_sidebar',array(
						array('custom_archive_services_layout_enable', '=', 1),
						array('archive_services_sidebar_layout', '=', array('left','right'))),'services-sidebar'
					),
					$this->get_sidebar_width('archive_services_sidebar_width',array(
						array('custom_archive_services_layout_enable', '=', 1),
						array('archive_services_sidebar_layout', '=', array('left','right'))
					)),
					$this->get_sidebar_mobile_enable('archive_services_sidebar_mobile_enable',array(
						array('custom_archive_services_layout_enable', '=', 1),
						array('archive_services_sidebar_layout', '=', array('left','right'))
					)),
					$this->get_content_padding('archive_services_content_padding',array('custom_archive_services_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
					// Single Services Layout
					$this->get_section_start('single_services_layout',esc_html__('Single Services','pithree')),
					array(
						'id' => 'custom_single_services_layout_enable',
						'type' => 'button_set',
						'title' => esc_html__('Custom Layout', 'pithree'),
						'subtitle' => esc_html__('Turn on this option if you want to enable custom layout on single services', 'pithree'),
						'desc' => '',
						'options' => g5plus_get_toggle(),
						'default' => 0
					),
					$this->get_page_layout('single_services_layout',array('custom_single_services_layout_enable', '=', 1)),
					$this->get_sidebar_layout('single_services_sidebar_layout', array('custom_single_services_layout_enable', '=', 1)),
					$this->get_sidebar('single_services_sidebar',array(
						array('custom_single_services_layout_enable', '=', 1),
						array('single_services_sidebar_layout', '=', array('left','right'))),'services-sidebar'
					),
					$this->get_sidebar_width('single_services_sidebar_width',array(
						array('custom_single_services_layout_enable', '=', 1),
						array('single_services_sidebar_layout', '=', array('left','right'))
					)),
					$this->get_sidebar_mobile_enable('single_services_sidebar_mobile_enable',array(
						array('custom_single_services_layout_enable', '=', 1),
						array('single_services_sidebar_layout', '=', array('left','right'))
					)),
					$this->get_content_padding('single_services_content_padding',array('custom_single_services_layout_enable', '=', 1),array('padding-top' => '50px', 'padding-bottom' => '50px', 'units' => 'px')),
		        )
	        );

	        // Page Title & Breadcrumb
	        $this->sections[] = array(
		        'title' => esc_html__('Page Title','pithree'),
		        'icon' => 'el el-asterisk',
		        'fields' => array(
			        $this->get_page_title_enable('page_title_enable'),
			        $this->get_page_title_layout('page_title_layout',array('page_title_enable', '=', 1)),
					$this->get_page_title_title_color('page_title_title_color',array('page_title_enable', '=', 1)),
			        $this->get_page_sub_title('page_sub_title',array('page_title_enable', '=', 1)),
			        $this->get_page_title_padding('page_title_padding',array('page_title_enable', '=', 1)),
			        $this->get_page_title_background_overlay('page_title_bg_overlay',array('page_title_enable', '=', 1)),
			        $this->get_page_title_background_image('page_title_bg_image',array('page_title_enable', '=', 1),$page_title_bg),
			        $this->get_page_title_parallax('page_title_parallax',array(array('page_title_enable', '=', 1),array('page_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('breadcrumbs_enable',array('page_title_enable' ,'=', 1)),
			        // Archive Title
			        $this->get_section_start('blog_title',esc_html__('Blog','pithree')),
			        array(
				        'id' => 'custom_blog_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('blog_title_enable',array('custom_blog_title_enable', '=', 1)),
			        $this->get_page_title_layout('blog_title_layout',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('blog_title_title_color',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1))),
			        $this->get_page_sub_title('blog_sub_title',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1))),
			        $this->get_page_title_padding('blog_title_padding',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('blog_title_bg_overlay',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1))),
			        $this->get_page_title_background_image('blog_title_bg_image',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('blog_title_parallax',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1),array('blog_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('blog_breadcrumbs_enable',array(array('custom_blog_title_enable', '=', 1),array('blog_title_enable', '=', 1))),
			        // Single Blog Title
			        $this->get_section_start('single_blog_title',esc_html__('Single Blog','pithree')),
			        array(
				        'id' => 'custom_single_blog_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('single_blog_title_enable',array('custom_single_blog_title_enable', '=', 1)),
			        $this->get_page_title_layout('single_blog_title_layout',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('single_blog_title_title_color',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1))),
			        $this->get_page_sub_title('single_blog_sub_title',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1))),
			        $this->get_page_title_padding('single_blog_title_padding',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('single_blog_title_bg_overlay',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1))),
			        $this->get_page_title_background_image('single_blog_title_bg_image',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('single_blog_title_parallax',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1),array('single_blog_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('single_blog_breadcrumbs_enable',array(array('custom_single_blog_title_enable', '=', 1),array('single_blog_title_enable', '=', 1))),
			        // Archive Product Title
			        $this->get_section_start('archive_product_title',esc_html__('Archive Product','pithree')),
			        array(
				        'id' => 'custom_archive_product_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on archive product', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('archive_product_title_enable',array('custom_archive_product_title_enable', '=', 1)),
			        $this->get_page_title_layout('archive_product_title_layout',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('archive_product_title_title_color',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1))),
					$this->get_page_sub_title('archive_product_sub_title',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1))),
			        $this->get_page_title_padding('archive_product_title_padding',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('archive_product_title_bg_overlay',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1))),
			        $this->get_page_title_background_image('archive_product_title_bg_image',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('archive_product_title_parallax',array(array('custom_archive_product_title_enable', '=', 1),array('archive_product_title_enable', '=', 1),array('archive_product_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('archive_product_breadcrumbs_enable',array(array('custom_product_archive_title_enable', '=', 1),array('archive_product_title_enable', '=', 1))),
			        // Single Product Title
			        $this->get_section_start('single_product_title',esc_html__('Single Product','pithree')),
			        array(
				        'id' => 'custom_single_product_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on single product', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('single_product_title_enable',array('custom_single_product_title_enable', '=', 1)),
			        $this->get_page_title_layout('single_product_title_layout',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('single_product_title_title_color',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1))),
					$this->get_page_sub_title('single_product_sub_title',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1))),
			        $this->get_page_title_padding('single_product_title_padding',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('single_product_title_bg_overlay',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1))),
			        $this->get_page_title_background_image('single_product_title_bg_image',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('single_product_title_parallax',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1),array('single_product_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('single_product_breadcrumbs_enable',array(array('custom_single_product_title_enable', '=', 1),array('single_product_title_enable', '=', 1))),
			        // Archive Portfolio Title
			        $this->get_section_start('archive_portfolio_title',esc_html__('Archive Portfolio','pithree')),
			        array(
				        'id' => 'custom_archive_portfolio_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on archive portfolio', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('archive_portfolio_title_enable',array('custom_archive_portfolio_title_enable', '=', 1)),
			        $this->get_page_title_layout('archive_portfolio_title_layout',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('archive_portfolio_title_title_color',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1))),
					$this->get_page_sub_title('archive_portfolio_sub_title',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_padding('archive_portfolio_title_padding',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('archive_portfolio_title_bg_overlay',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_background_image('archive_portfolio_title_bg_image',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('archive_portfolio_title_parallax',array(array('custom_archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1),array('archive_portfolio_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('archive_portfolio_breadcrumbs_enable',array(array('custom_product_archive_title_enable', '=', 1),array('archive_portfolio_title_enable', '=', 1))),
			        // Single Portfolio Title
			        $this->get_section_start('single_poftfolio_title',esc_html__('Single Portfolio','pithree')),
			        array(
				        'id' => 'custom_single_portfolio_title_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Custom Page Title', 'pithree'),
				        'subtitle' => esc_html__('Turn on this option if you want to enable custom title on single portfolio', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        $this->get_page_title_enable('single_portfolio_title_enable',array('custom_single_portfolio_title_enable', '=', 1)),
			        $this->get_page_title_layout('single_portfolio_title_layout',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1)) ),
					$this->get_page_title_title_color('single_portfolio_title_color',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1))),
					$this->get_page_sub_title('single_portfolio_sub_title',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_padding('single_portfolio_title_padding',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_background_overlay('single_portfolio_bg_overlay',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1))),
			        $this->get_page_title_background_image('single_portfolio_title_bg_image',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1)),$page_title_bg),
			        $this->get_page_title_parallax('single_portfolio_title_parallax',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1),array('single_portfolio_title_bg_image', '!=', ''))),
			        $this->get_breadcrumb_enable('single_portfolio_breadcrumbs_enable',array(array('custom_single_portfolio_title_enable', '=', 1),array('single_portfolio_title_enable', '=', 1))),

		        )
	        );

	        // Blog & Single Blog
	        $this->sections[] = array(
		        'title'  => esc_html__( 'Blog & Single Blog', 'pithree' ),
		        'desc'   => '',
		        'icon'   => 'el el-blogger',
		        'fields' => array(
			        $this->get_section_start('blog',esc_html__('Blog Options','pithree')),
                    array(
                        'id' => 'post_layout',
                        'type' => 'select',
                        'title' => esc_html__('Post Layout', 'pithree'),
                        'subtitle' => '',
                        'desc' => '',
                        'options' => g5plus_get_post_layout(),
                        'default' => 'large-image'
                    ),
                    array(
                        'id' => 'post_column',
                        'type' => 'select',
                        'title' => esc_html__('Post Columns', 'pithree'),
                        'subtitle' => '',
                        'options' => g5plus_get_post_columns(),
                        'desc' => '',
                        'default' => 2,
                        'required' => array('post_layout','=',array('masonry')),
                    ),
                    array(
                        'id' => 'post_paging',
                        'type' => 'button_set',
                        'title' => esc_html__('Post Paging', 'pithree'),
                        'subtitle' => '',
                        'desc' => '',
                        'options' => g5plus_get_paging_style(),
                        'default' => 'navigation'
                    ),
			        $this->get_section_start('single_blog',esc_html__('Single Blog Options','pithree')),

			        array(
				        'id' => 'single_tag_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Tags', 'pithree'),
				        'subtitle' => esc_html__('Turn Off this option if you want to hide tags on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 1
			        ),

			        array(
				        'id' => 'single_share_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Share', 'pithree'),
				        'subtitle' => esc_html__('Turn Off this option if you want to hide share on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 1
			        ),

			        array(
				        'id' => 'single_navigation_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Navigation', 'pithree'),
				        'subtitle' => esc_html__('Turn Off this option if you want to hide navigation on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 0
			        ),
			        array(
				        'id' => 'single_author_info_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Author Info', 'pithree'),
				        'subtitle' => esc_html__('Turn Off this option if you want to hide author info area on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 1
			        ),

			        array(
				        'id' => 'single_related_post_enable',
				        'type' => 'button_set',
				        'title' => esc_html__('Related Post', 'pithree'),
				        'subtitle' => esc_html__('Turn Off this option if you want to hide related post area on single blog', 'pithree'),
				        'desc' => '',
				        'options' => g5plus_get_toggle(),
				        'default' => 1
			        ),

			        array(
				        'id'       => 'single_related_post_total',
				        'type'     => 'text',
				        'title'    => esc_html__('Related Post Total', 'pithree'),
				        'subtitle' => esc_html__('Total record of Related Post.', 'pithree'),
				        'validate' => 'number',
				        'default'  => 6,
				        'required'  => array('single_related_post_enable', '=', 1),
			        ),

			        array(
				        'id'       => 'single_related_post_column',
				        'type'     => 'select',
				        'title'    => esc_html__('Related Post Columns', 'pithree'),
				        'default'  => 3,
				        'options' => array(3 => '3',4 => '4'),
				        'select2' => array('allowClear' =>  false) ,
				        'required'  => array('single_related_post_enable', '=', 1),
			        ),

			        array(
				        'id' => 'single_related_post_condition',
				        'type' => 'checkbox',
				        'title' => esc_html__('Related Post Condition', 'pithree'),
				        'options' => array(
					        'category' => esc_html__('Same Category','pithree'),
					        'tag' => esc_html__('Same Tag','pithree'),
				        ),
				        'default' => array(
					        'category'      => '1',
					        'tag'      => '1',
				        ),
				        'required'  => array('single_related_post_enable', '=', 1),
			        ),

		        )
	        );

            // Logo
            $this->sections[] = array(
                'title'  => esc_html__( 'Logo Setting', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-leaf',
                'fields' => array(
	                array(
		                'id' => 'section-logo-desktop',
		                'type' => 'section',
		                'title' => esc_html__('Logo Desktop', 'pithree'),
		                'indent' => true
	                ),
                    array(
                        'id' => 'logo',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Logo', 'pithree'),
                        'subtitle' => esc_html__('Upload your logo here.', 'pithree'),
                        'desc' => '',
                        'default' => array(
                            'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo.png'
                        )
                    ),
	                array(
		                'id' => 'logo_retina',
		                'type' => 'media',
		                'url'=> true,
		                'title' => esc_html__('Logo Retina', 'pithree'),
		                'subtitle' => esc_html__('Upload your logo retina here.', 'pithree'),
		                'desc' => '',
		                'default' => array(
			                'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo-2x.png'
		                )
	                ),
	                array(
		                'id' => 'sticky_logo',
		                'type' => 'media',
		                'url'=> true,
		                'title' => esc_html__('Sticky Logo', 'pithree'),
		                'subtitle' => esc_html__('Upload a sticky version of your logo here', 'pithree'),
		                'desc' => '',
		                'default' => array(
			                'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo.png'
		                )
	                ),
	                array(
		                'id' => 'sticky_logo_retina',
		                'type' => 'media',
		                'url'=> true,
		                'title' => esc_html__('Sticky Logo Retina', 'pithree'),
		                'subtitle' => esc_html__('Upload a sticky version of your logo retina here', 'pithree'),
		                'desc' => '',
		                'default' => array(
			                'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo-2x.png'
		                )
	                ),
	                array(
		                'id'        => 'logo_max_height',
		                'type'      => 'dimensions',
		                'title'     => esc_html__('Logo Max Height', 'pithree'),
		                'desc'      => esc_html__('You can set a max height for the logo here', 'pithree'),
		                'units' => false,
		                'width'    =>  false,
		                'default'  => array(
			                'height'  => ''
		                )
	                ),
	                array(
		                'id'             => 'logo_padding',
		                'type'           => 'spacing',
		                'mode'           => 'padding',
		                'units'          => 'px',
		                'units_extended' => 'false',
		                'title'          => esc_html__('Logo Top/Bottom Padding', 'pithree'),
		                'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
		                'desc'           => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'pithree'),
		                'left'          => false,
		                'right'          => false,
		                'default'            => array(
			                'padding-top'     => '',
			                'padding-bottom'  => '',
			                'units'          => 'px',
		                )
	                ),

	                array(
		                'id' => 'section-logo-mobile',
		                'type' => 'section',
		                'title' => esc_html__('Logo Mobile', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id' => 'mobile_logo',
		                'type' => 'media',
		                'url'=> true,
		                'title' => esc_html__('Mobile Logo', 'pithree'),
		                'subtitle' => esc_html__('Upload your logo here.', 'pithree'),
		                'desc' => '',
		                'default' => array(
			                'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo-mobile.png'
		                )
	                ),
	                array(
		                'id' => 'mobile_logo_retina',
		                'type' => 'media',
		                'url'=> true,
		                'title' => esc_html__('Mobile Logo Retina', 'pithree'),
		                'subtitle' => esc_html__('Upload your logo retina here.', 'pithree'),
		                'desc' => '',
		                'default' => array(
			                'url' => G5PLUS_THEME_URL . 'assets/images/theme-options/logo-mobile-2x.png'
		                )
	                ),
	                array(
		                'id'        => 'mobile_logo_max_height',
		                'type'      => 'dimensions',
		                'title'     => esc_html__('Mobile Logo Max Height', 'pithree'),
		                'desc'      => esc_html__('You can set a max height for the logo mobile here', 'pithree'),
		                'units'     => false,
		                'width'    =>  false,
		                'default'  => array(
			                'height'  => ''
		                )
	                ),
	                array(
		                'id'             => 'mobile_logo_padding',
		                'type'           => 'spacing',
		                'mode'           => 'padding',
		                'units'          => 'px',
		                'units_extended' => 'false',
		                'title'          => esc_html__('Logo Top/Bottom Padding', 'pithree'),
		                'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
		                'desc'           => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'pithree'),
		                'left'          => false,
		                'right'          => false,
		                'default'            => array(
			                'padding-top'     => '',
			                'padding-bottom'  => '',
			                'units'          => 'px',
		                )
	                ),

                )
            );

	        // Top Drawer
	        $this->sections[] = array(
		        'title'  => esc_html__( 'Top Drawer', 'pithree' ),
		        'desc'   => '',
		        'icon'   => 'el el-photo',
		        'fields' => array(
			        array(
				        'id'       => 'top_drawer_type',
				        'type'     => 'button_set',
				        'title'    => esc_html__( 'Top Drawer Type', 'pithree' ),
				        'subtitle' => esc_html__( 'Set top drawer type.', 'pithree' ),
				        'desc'     => '',
				        'options'  => array( 'none' => 'Disable', 'show' => 'Always Show', 'toggle' => 'Toggle' ),
				        'default'  => 'none'
			        ),
			        array(
				        'id'       => 'top_drawer_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Top Drawer Sidebar', 'pithree'),
				        'subtitle' => "Choose the default top drawer sidebar",
				        'data'      => 'sidebars',
				        'desc' => '',
				        'default' => 'top_drawer_sidebar',
				        'required' => array('top_drawer_type','=',array('show','toggle')),
			        ),

			        array(
				        'id' => 'top_drawer_wrapper_layout',
				        'type' => 'button_set',
				        'title' => esc_html__('Top Drawer Wrapper Layout', 'pithree'),
				        'subtitle' => esc_html__('Select top drawer wrapper layout', 'pithree'),
				        'desc' => '',
				        'options' => array('full' => 'Full Width','container' => 'Container', 'container-fluid' => 'Container Fluid'),
				        'default' => 'container',
				        'required' => array('top_drawer_type','=',array('show','toggle')),
			        ),

			        array(
				        'id'       => 'top_drawer_hide_mobile',
				        'type'     => 'button_set',
				        'title'    => esc_html__( 'Show/Hide Top Drawer on mobile', 'pithree' ),
				        'desc'     => '',
				        'options'  => array( '1' => 'On', '0' => 'Off' ),
				        'default'  => '1',
				        'required' => array('top_drawer_type','=',array('show','toggle')),
			        ),
			        array(
				        'id'             => 'top_drawer_padding',
				        'type'           => 'spacing',
				        'mode'           => 'padding',
				        'units'          => 'px',
				        'units_extended' => 'false',
				        'title'          => esc_html__('Logo Top/Bottom Padding', 'pithree'),
				        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
				        'desc'           => esc_html__('If you would like to override the default top drawer top/bottom padding, then you can do so here.', 'pithree'),
				        'left'          => false,
				        'right'          => false,
				        'default'            => array(
					        'padding-top'     => '',
					        'padding-bottom'  => '',
					        'units'          => 'px',
				        ),
				        'required' => array('top_drawer_type','=',array('show','toggle')),
			        ),
		        )
	        );

	        // Top Bar
	        $this->sections[] = array(
		        'title'  => esc_html__( 'Top Bar', 'pithree' ),
		        'desc'   => esc_html__( 'Setting for Top Bar', 'pithree' ),
		        'icon'   => 'el el-minus',
		        'fields' => array(
			        array(
				        'id' => 'section-top-bar-desktop',
				        'type' => 'section',
				        'title' => esc_html__('Desktop Settings', 'pithree'),
				        'indent' => true
			        ),
			        array(
				        'id'       => 'top_bar_enable',
				        'type'     => 'button_set',
				        'title'    => esc_html__( 'Show/Hide Top Bar', 'pithree' ),
				        'subtitle' => esc_html__( 'Show Hide Top Bar.', 'pithree' ),
				        'desc'     => '',
				        'options'  => array( '1' => esc_html__('Show','pithree'), '0' => esc_html__('Hide','pithree') ),
				        'default'  => '0',
			        ),
			        array(
				        'id' => 'top_bar_layout',
				        'type' => 'image_select',
				        'title' => esc_html__('Top bar Layout', 'pithree'),
				        'subtitle' => esc_html__('Select the top bar column layout.', 'pithree'),
				        'desc' => '',
				        'options' => array(
					        'top-bar-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-1.jpg'),
					        'top-bar-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-2.jpg'),
					        'top-bar-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-3.jpg'),
					        'top-bar-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-4.jpg'),
				        ),
				        'default' => 'top-bar-1',
				        'required' => array('top_bar_enable','=','1'),
			        ),

			        array(
				        'id' => 'top_bar_left_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Top Left Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the default top left sidebar','pithree'),
				        'data'      => 'sidebars',
				        'desc' => '',
				        'default' => 'top_bar_left',
				        'required' => array('top_bar_enable','=','1'),
			        ),
			        array(
				        'id' => 'top_bar_right_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Top Right Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the default top right sidebar','pithree'),
				        'data'      => 'sidebars',
				        'desc' => '',
				        'default' => 'top_bar_right',
				        'required' => array('top_bar_enable','=','1'),
			        ),
			        array(
				        'id'        => 'top_bar_border',
				        'type'      => 'button_set',
				        'title'     => esc_html__('Top bar border', 'pithree'),
				        'options'  => array(
					        'none'              => esc_html__('None','pithree'),
					        'full-border'       => esc_html__('Full Border','pithree'),
					        'container-border'  => esc_html__('Container Border','pithree'),
				        ),
				        'default'  => 'none',
				        'required' => array('top_bar_enable','=','1'),
			        ),
			        array(
				        'id'             => 'top_bar_padding',
				        'type'           => 'spacing',
				        'mode'           => 'padding',
				        'units'          => 'px',
				        'units_extended' => 'false',
				        'title'          => esc_html__('Top Bar Top/Bottom Padding', 'pithree'),
				        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
				        'desc'           => esc_html__('If you would like to override the default top bar top/bottom padding, then you can do so here.', 'pithree'),
				        'left'          => false,
				        'right'          => false,
				        'default'            => array(
					        'padding-top'     => '',
					        'padding-bottom'  => '',
					        'units'          => 'px',
				        ),
				        'required' => array('top_bar_enable','=','1'),
			        ),

			        //--------------------------------------------------------------
			        array(
				        'id' => 'section-top-bar-mobile',
				        'type' => 'section',
				        'title' => esc_html__('Mobile Settings', 'pithree'),
				        'indent' => true
			        ),
			        array(
				        'id'       => 'top_bar_mobile_enable',
				        'type'     => 'button_set',
				        'title'    => esc_html__( 'Show/Hide Top Bar', 'pithree' ),
				        'subtitle' => esc_html__( 'Show Hide Top Bar.', 'pithree' ),
				        'desc'     => '',
				        'options'  => array( '1' => esc_html__('Show','pithree'), '0' => esc_html__('Hide','pithree') ),
				        'default'  => '0',
			        ),
			        array(
				        'id' => 'top_bar_mobile_layout',
				        'type' => 'image_select',
				        'title' => esc_html__('Top bar Layout', 'pithree'),
				        'subtitle' => esc_html__('Select the top bar column layout.', 'pithree'),
				        'desc' => '',
				        'options' => array(
					        'top-bar-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-1.jpg'),
					        'top-bar-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-2.jpg'),
					        'top-bar-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-3.jpg'),
					        'top-bar-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/top-bar-layout-4.jpg'),
				        ),
				        'default' => 'top-bar-1',
				        'required' => array('top_bar_mobile_enable','=','1'),
			        ),

			        array(
				        'id' => 'top_bar_mobile_left_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Top Left Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the default top left sidebar','pithree'),
				        'data'      => 'sidebars',
				        'desc' => '',
				        'default' => 'top_bar_left',
				        'required' => array('top_bar_mobile_enable','=','1'),
			        ),
			        array(
				        'id' => 'top_bar_mobile_right_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Top Right Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the default top right sidebar','pithree'),
				        'data'      => 'sidebars',
				        'desc' => '',
				        'default' => 'top_bar_right',
				        'required' => array('top_bar_mobile_enable','=','1'),
			        ),
			        array(
				        'id'        => 'top_bar_mobile_border',
				        'type'      => 'button_set',
				        'title'     => esc_html__('Top bar mobile border', 'pithree'),
				        'options'  => array(
					        'none'              => esc_html__('None','pithree'),
					        'full-border'       => esc_html__('Full Border','pithree'),
					        'container-border'  => esc_html__('Container Border','pithree'),
				        ),
				        'default'  => 'container-border',
				        'required' => array('top_bar_mobile_enable','=','1'),
			        ),
			        array(
				        'id'             => 'top_bar_mobile_padding',
				        'type'           => 'spacing',
				        'mode'           => 'padding',
				        'units'          => 'px',
				        'units_extended' => 'false',
				        'title'          => esc_html__('Top Bar Top/Bottom Padding', 'pithree'),
				        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
				        'desc'           => esc_html__('If you would like to override the default top bar top/bottom padding, then you can do so here.', 'pithree'),
				        'left'          => false,
				        'right'          => false,
				        'default'            => array(
					        'padding-top'     => '',
					        'padding-bottom'  => '',
					        'units'          => 'px',
				        ),
				        'required' => array('top_bar_enable','=','1'),
			        ),
		        )
	        );

            // Header
            $this->sections[] = array(
                'title'  => esc_html__( 'Header', 'pithree' ),
	            'desc'   => esc_html__( 'Setting for Theme Header', 'pithree' ),
                'icon'   => 'el el-credit-card',
                'fields' => array(
	                array(
		                'id'       => 'header_responsive_breakpoint',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Header responsive breakpoint', 'pithree' ),
		                'subtitle' => esc_html__( 'Set header responsive breakpoint', 'pithree' ),
		                'desc'     => '',
		                'options'  => array(
			                '991' => esc_html__('Medium Devices: < 992px','pithree'),
			                '767' => esc_html__('Tablet Portrait: < 768px','pithree'),
		                ),
		                'default'  => '991'
	                ),
	                array(
		                'id' => 'section-header-desktop',
		                'type' => 'section',
		                'title' => esc_html__('Desktop Settings', 'pithree'),
		                'indent' => true
	                ),
                    array(
                        'id' => 'header_layout',
                        'type' => 'image_select',
                        'title' => esc_html__('Header Layout', 'pithree'),
                        'subtitle' => esc_html__('Select a header layout option from the examples.', 'pithree'),
                        'desc' => '',
                        'options' => array(
                            'header-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-1.png'),
	                        'header-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-2.png'),
	                        'header-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-3.png'),
	                        'header-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-4.png'),
	                        'header-5' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-5.png'),
                        ),
                        'default' => 'header-1'
                    ),
	                array(
		                'id'        => 'header_container_layout',
		                'type'      => 'button_set',
		                'title'     => esc_html__('Header container layout', 'pithree'),
		                'options'  => array(
			                'container'     => esc_html__('Container','pithree'),
			                'container-full'      => esc_html__('Container Full','pithree'),
		                ),
		                'default'  => 'container'
	                ),
	                array(
		                'id'       => 'header_float',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Header Float', 'pithree' ),
		                'subtitle' => esc_html__( 'Enable/Disable Header Float.', 'pithree' ),
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => '0',
	                ),
                    array(
		                'id'       => 'header_sticky',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show/Hide Header Sticky', 'pithree' ),
		                'subtitle' => esc_html__( 'Show Hide header Sticky.', 'pithree' ),
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => '1'
	                ),
	                array(
		                'id'       => 'header_border_bottom',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Header border bottom', 'pithree' ),
		                'subtitle' => esc_html__( 'Set header border bottom', 'pithree' ),
		                'desc'     => '',
		                'options'  => array(
			                'none'              => esc_html__('None','pithree'),
			                'full-border'       => esc_html__('Full Border','pithree'),
			                'container-border'  => esc_html__('Container Border','pithree'),
		                ),
		                'default'  => 'none',
		                'required' => array('header_layout', '=', array('header-1', 'header-3')),
	                ),
	                array(
		                'id'       => 'header_above_border_bottom',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Header above border bottom', 'pithree' ),
		                'subtitle' => esc_html__( 'Set header above border bottom', 'pithree' ),
		                'desc'     => '',
		                'options'  => array(
			                'none'              => esc_html__('None','pithree'),
			                'full-border'       => esc_html__('Full Border','pithree'),
			                'container-border'  => esc_html__('Container Border','pithree'),
		                ),
		                'default'  => 'none',
		                'required' => array('header_layout', '=', array('header-3')),
	                ),
	                array(
		                'id'             => 'header_padding',
		                'type'           => 'spacing',
		                'mode'           => 'padding',
		                'units'          => 'px',
		                'units_extended' => 'false',
		                'title'          => esc_html__('Header Top/Bottom Padding', 'pithree'),
		                'subtitle'       => esc_html__('This must be numeric (no px). Leave blank for default.', 'pithree'),
		                'desc'           => esc_html__('If you would like to override the default header top/bottom padding, then you can do so here.', 'pithree'),
		                'left'          => false,
		                'right'          => false,
		                'default'            => array(
			                'padding-top'     => '',
			                'padding-bottom'  => '',
			                'units'          => 'px',
		                ),
	                ),
	                array(
		                'id'        => 'navigation_height',
		                'type'      => 'dimensions',
		                'title'     => esc_html__('Navigation height', 'pithree'),
		                'desc'      => esc_html__('Set header navigation height (px). Do not include unit. Empty to default', 'pithree'),
		                'units'     => false,
		                'width'    =>  false,
		                'default'  => array(
			                'height'  => ''
		                ),
						'required' => array('header_layout', '!=', 'header-1'),
	                ),
	                array(
		                'id'        => 'navigation_spacing',
		                'type'      => 'slider',
		                'title'     => esc_html__('Navigation Spacing (px)', 'pithree'),
		                'default'   => '40',
		                'min'       => 0,
		                'step'      => 1,
		                'max'       => 100,
	                ),

	                //---------------------------------------------------------------
	                array(
		                'id' => 'section-header-mobile',
		                'type' => 'section',
		                'title' => esc_html__('Mobile Settings', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id' => 'mobile_header_layout',
		                'type' => 'image_select',
		                'title' => esc_html__('Header Layout', 'pithree'),
		                'subtitle' => esc_html__('Select header mobile layout', 'pithree'),
		                'desc' => '',
		                'options' => array(
			                'header-mobile-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-mobile-layout-1.png'),
			                'header-mobile-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-mobile-layout-2.png'),
			                'header-mobile-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-mobile-layout-3.png'),
			                'header-mobile-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/header-mobile-layout-4.png'),
		                ),
		                'default' => 'header-mobile-1'
	                ),
	                array(
		                'id'       => 'mobile_header_menu_drop',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Menu Drop Type', 'pithree' ),
		                'subtitle' => esc_html__( 'Set menu drop type for mobile header', 'pithree' ),
		                'desc'     => '',
		                'options'  => array(
			                'menu-drop-dropdown' => esc_html__('Dropdown Menu','pithree'),
			                'menu-drop-fly' => esc_html__('Fly Menu','pithree')
		                ),
		                'default'  => 'menu-drop-fly'
	                ),
	                array(
		                'id'       => 'mobile_header_stick',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Stick Mobile Header', 'pithree' ),
		                'subtitle' => esc_html__( 'Enable Stick Mobile Header.', 'pithree' ),
		                'desc'     => '',
		                'options'  => array( '1' => esc_html__('On','pithree'), '0' => esc_html__('Off','pithree') ),
		                'default'  => '0'
	                ),
	                array(
		                'id'       => 'mobile_header_search_box',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Search Box', 'pithree' ),
		                'subtitle' => esc_html__( 'Enable Search Box.', 'pithree' ),
		                'desc'     => '',
		                'options'  => array( '1' => esc_html__('Show','pithree'), '0' => esc_html__('Hide','pithree') ),
		                'default'  => '1'
	                ),
	                array(
		                'id'       => 'mobile_header_shopping_cart',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Shopping Cart', 'pithree' ),
		                'subtitle' => esc_html__( 'Enable Shopping Cart', 'pithree' ),
		                'desc'     => '',
		                'options'  => array( '1' => esc_html__('Show','pithree'), '0' => esc_html__('Hide','pithree') ),
		                'default'  => '1'
	                ),
	                array(
		                'id'        => 'mobile_header_border_bottom',
		                'type'      => 'button_set',
		                'title'     => esc_html__('Mobile header border bottom', 'pithree'),
		                'options'  => array(
			                'none'              => esc_html__('None','pithree'),
			                'full-border'       => esc_html__('Full Border','pithree'),
			                'container-border'  => esc_html__('Container Border','pithree'),
		                ),
		                'default'  => 'none',
	                ),
                )
            );

	        // Header Customize
	        $this->sections[] = array(
		        'title'  => esc_html__( 'Header Customize', 'pithree' ),
		        'desc'   => '',
		        'icon'   => 'el el-credit-card',
		        'fields' => array(
			        array(
				        'id' => 'section-header-customize-nav',
				        'type' => 'section',
				        'title' => esc_html__('Header Customize Navigation', 'pithree'),
				        'indent' => true,
			        ),
			        array(
				        'id'      => 'header_customize_nav',
				        'type'    => 'sorter',
				        'title'   => 'Header customize navigation',
				        'desc'    => 'Organize how you want the layout to appear on the header navigation',
				        'options' => array(
					        'enabled'  => array(
								'search'        => esc_html__('Search','pithree'),
					        ),
					        'disabled' => array(
						        'email'         => esc_html__('Email','pithree'),
						        'phone'         => esc_html__('Phone','pithree'),
								'openingtime'   => esc_html__('Opening Time', 'pithree'),
						        'shopping-cart' => esc_html__('Shopping Cart','pithree'),
						        'sidebar'       => esc_html__('Sidebar','pithree'),
						        'custom-text'   => esc_html__('Custom Text','pithree'),
					        )
				        )
			        ),
			        array(
				        'id' => 'header_customize_nav_email',
				        'type' => 'label_value',
				        'title' => esc_html__('Email', 'pithree'),
				        'default' => array(
							'label' => esc_html__('Email Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
			        array(
				        'id' => 'header_customize_nav_phone',
				        'type' => 'label_value',
				        'title' => esc_html__('Phone', 'pithree'),
				        'default' => array(
					        'label' => esc_html__('Call Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
					array(
						'id' => 'header_customize_nav_openingtime',
						'type' => 'label_value',
						'title' => esc_html__('Opening Time', 'pithree'),
						'default' => array(
							'label' => esc_html__('Opening Time', 'pithree'),
							'value' => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
						),
					),
			        array(
				        'id' => 'header_customize_nav_search',
				        'type' => 'button_set',
				        'title' => esc_html__('Search Type', 'pithree'),
				        'default' => 'button',
				        'options' => array(
					        'button' => esc_html__('Button','pithree'),
					        'box' => esc_html__('Box','pithree'),
					        'product-category' => esc_html__('Product Category','pithree'),
				        ),
			        ),
			        array(
				        'id' => 'header_customize_nav_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the sidebar for header customize navigation','pithree'),
				        'data'      => 'sidebars',
				        'default' => '',
			        ),
			        array(
				        'id' => 'header_customize_nav_text',
				        'type' => 'ace_editor',
				        'mode' => 'html',
				        'theme' => 'monokai',
				        'title' => esc_html__('Custom Text Content', 'pithree'),
				        'subtitle' => esc_html__('Add Content for Custom Text', 'pithree'),
				        'desc' => '',
				        'default' => '',
				        'options'  => array('minLines'=> 5, 'maxLines' => 60),
			        ),
			        array(
				        'id'        => 'header_customize_nav_spacing',
				        'type'      => 'slider',
				        'title'     => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				        'default'   => '40',
				        'min'       => 0,
				        'step'      => 1,
				        'max'       => 100,
			        ),


			        array(
				        'id' => 'section-header-customize-left',
				        'type' => 'section',
				        'title' => esc_html__('Header Customize Left', 'pithree'),
				        'indent' => true,
				        'required' => array('header_layout', '=', 'header-3'),
			        ),
			        array(
				        'id'      => 'header_customize_left',
				        'type'    => 'sorter',
				        'title'   => 'Header customize left',
				        'desc'    => 'Organize how you want the layout to appear on the header left',
				        'options' => array(
					        'enabled'  => array(
					        ),
					        'disabled' => array(
								'email'         => esc_html__('Email','pithree'),
								'phone'         => esc_html__('Phone','pithree'),
								'openingtime'   => esc_html__('Opening Time', 'pithree'),
								'shopping-cart' => esc_html__('Shopping Cart','pithree'),
						        'search' => esc_html__('Search','pithree'),
						        'sidebar'       => esc_html__('Sidebar','pithree'),
						        'custom-text'   => esc_html__('Custom Text','pithree'),
					        )
				        )
			        ),
			        array(
				        'id' => 'header_customize_left_email',
				        'type' => 'label_value',
				        'title' => esc_html__('Email', 'pithree'),
				        'default' => array(
					        'label' => esc_html__('Email Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
			        array(
				        'id' => 'header_customize_left_phone',
				        'type' => 'label_value',
				        'title' => esc_html__('Phone', 'pithree'),
				        'default' => array(
					        'label' => esc_html__('Call Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
					array(
						'id' => 'header_customize_left_openingtime',
						'type' => 'label_value',
						'title' => esc_html__('Opening Time', 'pithree'),
						'default' => array(
							'label' => esc_html__('Opening Time', 'pithree'),
							'value' => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
						),
					),
			        array(
				        'id' => 'header_customize_left_search',
				        'type' => 'button_set',
				        'title' => esc_html__('Search Type', 'pithree'),
				        'default' => 'button',
				        'options' => array(
					        'button' => esc_html__('Button','pithree'),
					        'box' => esc_html__('Box','pithree'),
					        'product-category' => esc_html__('Product Category','pithree'),
				        ),
			        ),
			        array(
				        'id' => 'header_customize_left_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the sidebar for header right customize','pithree'),
				        'data'      => 'sidebars',
				        'default' => '',
			        ),
			        array(
				        'id' => 'header_customize_left_text',
				        'type' => 'ace_editor',
				        'mode' => 'html',
				        'theme' => 'monokai',
				        'title' => esc_html__('Custom Text Content', 'pithree'),
				        'subtitle' => esc_html__('Add Content for Custom Text', 'pithree'),
				        'desc' => '',
				        'default' => '',
				        'options'  => array('minLines'=> 5, 'maxLines' => 60),
			        ),
			        array(
				        'id'        => 'header_customize_left_spacing',
				        'type'      => 'slider',
				        'title'     => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				        'default'   => '40',
				        'min'       => 0,
				        'step'      => 1,
				        'max'       => 100,
			        ),

			        array(
				        'id' => 'section-header-customize-right',
				        'type' => 'section',
				        'title' => esc_html__('Header Customize Right', 'pithree'),
				        'indent' => true,
				        'required' => array('header_layout', '!=', 'header-1'),
			        ),
			        array(
				        'id'      => 'header_customize_right',
				        'type'    => 'sorter',
				        'title'   => 'Header customize right',
				        'desc'    => 'Organize how you want the layout to appear on the header right',
				        'options' => array(
					        'enabled'  => array(

					        ),
					        'disabled' => array(
						        'shopping-cart' => esc_html__('Shopping Cart','pithree'),
						        'search'        => esc_html__('Search','pithree'),
                                'email'         => esc_html__('Email','pithree'),
                                'phone'         => esc_html__('Phone','pithree'),
                                'openingtime'   => esc_html__('Opening Time', 'pithree'),
						        'sidebar'       => esc_html__('Sidebar','pithree'),
						        'custom-text'   => esc_html__('Custom Text','pithree'),
					        )
				        )
			        ),
			        array(
				        'id' => 'header_customize_right_email',
				        'type' => 'label_value',
				        'title' => esc_html__('Email', 'pithree'),
				        'default' => array(
					        'label' => esc_html__('Email Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
			        array(
				        'id' => 'header_customize_right_phone',
				        'type' => 'label_value',
				        'title' => esc_html__('Phone', 'pithree'),
				        'default' => array(
					        'label' => esc_html__('Call Us', 'pithree'),
					        'value' => '',
				        ),
			        ),
					array(
						'id' => 'header_customize_right_openingtime',
						'type' => 'label_value',
						'title' => esc_html__('Opening Time', 'pithree'),
						'default' => array(
							'label' => esc_html__('Opening Time', 'pithree'),
							'value' => esc_html__('Mon - Sat 8:00 - 18:00', 'pithree'),
						),
					),
			        array(
				        'id' => 'header_customize_right_search',
				        'type' => 'button_set',
				        'title' => esc_html__('Search Type', 'pithree'),
				        'default' => 'button',
				        'options' => array(
					        'button' => esc_html__('Button','pithree'),
					        'box' => esc_html__('Box','pithree'),
					        'product-category' => esc_html__('Product Category','pithree'),
				        ),
			        ),
			        array(
				        'id' => 'header_customize_right_sidebar',
				        'type' => 'select',
				        'title' => esc_html__('Sidebar', 'pithree'),
				        'subtitle' => esc_html__('Choose the sidebar for header right customize','pithree'),
				        'data'      => 'sidebars',
				        'default' => '',
			        ),
			        array(
				        'id' => 'header_customize_right_text',
				        'type' => 'ace_editor',
				        'mode' => 'html',
				        'theme' => 'monokai',
				        'title' => esc_html__('Custom Text Content', 'pithree'),
				        'subtitle' => esc_html__('Add Content for Custom Text', 'pithree'),
				        'desc' => '',
				        'default' => '',
				        'options'  => array('minLines'=> 5, 'maxLines' => 60),
			        ),
			        array(
				        'id'        => 'header_customize_right_spacing',
				        'type'      => 'slider',
				        'title'     => esc_html__('Navigation Item Spacing (px)', 'pithree'),
				        'default'   => '40',
				        'min'       => 0,
				        'step'      => 1,
				        'max'       => 100,
			        ),
		        )
	        );

	        // Footer
            $this->sections[] = array(
                'title'  => esc_html__( 'Footer', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-website',
                'fields' => array(
	                array(
		                'id' => 'section-footer-general-settings',
		                'type' => 'section',
		                'title' => esc_html__('General Settings', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id' => 'footer_container_layout',
		                'type' => 'button_set',
		                'title' => esc_html__('Footer Container Layout', 'pithree'),
		                'subtitle' => esc_html__('Select Footer Container Layout', 'pithree'),
		                'desc' => '',
		                'options' => array(
                            'full'              => esc_html__('Full Width','pithree'),
                            'container-fluid'   => esc_html__('Container Fluid','pithree'),
			                'container'         => esc_html__('Container','pithree')
                        ),
		                'default' => 'container'
	                ),


                    array(
                        'id' => 'footer_layout',
                        'type' => 'image_select',
                        'title' => esc_html__('Layout', 'pithree'),
                        'subtitle' => esc_html__('Select the footer column layout.', 'pithree'),
                        'desc' => '',
                        'options' => array(
                            'footer-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-1.jpg'),
                            'footer-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-2.jpg'),
                            'footer-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-3.jpg'),
                            'footer-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-4.jpg'),
                            'footer-5' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-5.jpg'),
                            'footer-6' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-6.jpg'),
                            'footer-7' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-7.jpg'),
                            'footer-8' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-8.jpg'),
                            'footer-9' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/footer-layout-9.jpg'),
                        ),
                        'default' => 'footer-1'
                    ),

	                array(
		                'id' => 'footer_sidebar_1',
		                'type' => 'select',
		                'title' => esc_html__('Sidebar 1', 'pithree'),
		                'subtitle' => "Choose the default footer sidebar 1",
		                'data'      => 'sidebars',
		                'desc' => '',
		                'default' => 'footer-1',
	                ),

	                array(
		                'id' => 'footer_sidebar_2',
		                'type' => 'select',
		                'title' => esc_html__('Sidebar 2', 'pithree'),
		                'subtitle' => "Choose the default footer sidebar 2",
		                'data'      => 'sidebars',
		                'desc' => '',
		                'default' => 'footer-2',
		                'required' => array('footer_layout', '=', array('footer-1','footer-2','footer-3','footer-4','footer-5','footer-6','footer-7','footer-8'))
	                ),

	                array(
		                'id' => 'footer_sidebar_3',
		                'type' => 'select',
		                'title' => esc_html__('Sidebar 3', 'pithree'),
		                'subtitle' => "Choose the default footer sidebar 3",
		                'data'      => 'sidebars',
		                'desc' => '',
		                'default' => 'footer-3',
		                'required' => array('footer_layout', '=', array('footer-1','footer-2','footer-3','footer-5','footer-8'))
	                ),

	                array(
		                'id' => 'footer_sidebar_4',
		                'type' => 'select',
		                'title' => esc_html__('Sidebar 4', 'pithree'),
		                'subtitle' => "Choose the default footer sidebar 4",
		                'data'      => 'sidebars',
		                'desc' => '',
		                'default' => 'footer-4',
		                'required' => array('footer_layout', '=', array('footer-1'))
	                ),
                    array(
                        'id' => 'footer_bg_image',
                        'type' => 'media',
                        'url'=> true,
                        'title' => esc_html__('Background image', 'pithree'),
                        'subtitle' => esc_html__('Upload footer background image here', 'pithree'),
                        'desc' => '',
	                    'default' => '',
                    ),

                    array(
                        'id'       => 'footer_parallax',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Footer Parallax', 'pithree' ),
                        'subtitle' => esc_html__( 'Enable Footer Parallax', 'pithree' ),
                        'desc'     => '',
                        'options'  => array( '1' => 'Enable', '0' => 'Disable' ),
                        'default'  => '0'
                    ),
                    array(
                        'id'       => 'collapse_footer',
                        'type'     => 'button_set',
                        'title'    => esc_html__( 'Collapse footer on mobile device', 'pithree' ),
                        'subtitle' => esc_html__( 'Enable collapse footer', 'pithree' ),
                        'desc'     => '',
                        'options'  => array( '1' => 'On', '0' => 'Off' ),
                        'default'  => '0'
                    ),
	                array(
		                'id'             => 'footer_padding',
		                'type'           => 'spacing',
		                'mode'           => 'padding',
		                'units'          => 'px',
		                'units_extended' => 'false',
		                'title'          => esc_html__('Footer Top/Bottom Padding', 'pithree'),
		                'subtitle'       => esc_html__('This must be numeric (no px)', 'pithree'),
		                'desc'           => esc_html__('If you would like to override the default footer top/bottom padding, then you can do so here.', 'pithree'),
		                'left'          => false,
		                'right'          => false,
		                'default'            => array(
			                'padding-top'     => '60px',
			                'padding-bottom'  => '60px',
			                'units'          => 'px',
		                )
	                ),
	                array(
		                'id'        => 'footer_border_top',
		                'type'      => 'button_set',
		                'title'     => esc_html__('Footer border top', 'pithree'),
		                'options'  => array(
			                'none'              => esc_html__('None','pithree'),
			                'full-border'       => esc_html__('Full Border','pithree'),
			                'container-border'  => esc_html__('Container Border','pithree'),
		                ),
		                'default'  => 'none',
	                ),

	                //--------------------------------------------------------------------------------
	                array(
		                'id' => 'section-footer-bottom-settings',
		                'type' => 'section',
		                'title' => esc_html__('Bottom Bar Settings', 'pithree'),
		                'indent' => true
	                ),
                    array(
                        'id' => 'bottom_bar_layout',
                        'type' => 'image_select',
                        'title' => esc_html__('Bottom bar Layout', 'pithree'),
                        'subtitle' => esc_html__('Select the bottom bar column layout.', 'pithree'),
                        'desc' => '',
                        'options' => array(
                            'bottom-bar-1' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/bottom-bar-layout-1.jpg'),
                            'bottom-bar-2' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/bottom-bar-layout-2.jpg'),
                            'bottom-bar-3' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/bottom-bar-layout-3.jpg'),
	                        'bottom-bar-4' => array('title' => '', 'img' => G5PLUS_THEME_URL.'assets/images/theme-options/bottom-bar-layout-4.jpg'),
                        ),
                        'default' => 'bottom-bar-1',
                    ),

                    array(
                        'id' => 'bottom_bar_left_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Bottom Left Sidebar', 'pithree'),
                        'subtitle' => "Choose the default bottom left sidebar",
                        'data'      => 'sidebars',
                        'desc' => '',
                        'default' => 'bottom_bar_left',
                    ),
                    array(
                        'id' => 'bottom_bar_right_sidebar',
                        'type' => 'select',
                        'title' => esc_html__('Bottom Right Sidebar', 'pithree'),
                        'subtitle' => "Choose the default bottom right sidebar",
                        'data'      => 'sidebars',
                        'desc' => '',
                        'default' => 'bottom_bar_right',
                    ),
	                array(
		                'id'             => 'bottom_bar_padding',
		                'type'           => 'spacing',
		                'mode'           => 'padding',
		                'units'          => 'px',
		                'units_extended' => 'false',
		                'title'          => esc_html__('Bottom Bar Top/Bottom Padding', 'pithree'),
		                'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'pithree'),
		                'desc'           => esc_html__('If you would like to override the default bottom bar top/bottom padding, then you can do so here.', 'pithree'),
		                'left'          => false,
		                'right'         => false,
		                'default'            => array(
			                'padding-top'     => '25px',
			                'padding-bottom'  => '25px',
			                'units'          => 'px',
		                ),
	                ),
	                array(
		                'id'        => 'bottom_bar_border_top',
		                'type'      => 'button_set',
		                'title'     => esc_html__('Bottom bar border top', 'pithree'),
		                'options'  => array(
			                'none'              => esc_html__('None','pithree'),
			                'full-border'       => esc_html__('Full Border','pithree'),
			                'container-border'  => esc_html__('Container Border','pithree'),
		                ),
		                'default'  => 'none',
	                ),
                )
            );

	        // Theme Colors
            $this->sections[] = array(
                'title'  => esc_html__( 'Theme Colors', 'pithree' ),
                'desc'   => esc_html__( 'If you change value in this section, you must "Save & Generate CSS"', 'pithree' ),
                'icon'   => 'el el-magic',
                'fields' => array(
	                array(
		                'id' => 'section-theme-color-general',
		                'type' => 'section',
		                'title' => esc_html__('General', 'pithree'),
		                'indent' => true
	                ),
                    array(
                        'id'       => 'primary_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Primary Color', 'pithree'),
                        'default'  => '#ffa60a',
                        'validate' => 'color',
	                    'colors' => array('#ffa60a', '#EA4336', '#4285F4', '#2F659A', '#C60325', '#35BFEE', '#FFC40E', '#6EA9AD')
                    ),
					array(
						'id'       => 'secondary_color',
						'type'     => 'color',
						'title'    => esc_html__('Secondary Color', 'pithree'),
						'default'  => '#2c3e50',
						'validate' => 'color',
						'colors' => array('#2c3e50', '#EA4336', '#4285F4', '#2F659A', '#C60325', '#35BFEE', '#FFC40E', '#6EA9AD')
					),
                    array(
                        'id'       => 'text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Text Color', 'pithree'),
                        'default'  => '#8a8a8a',
                        'validate' => 'color',
                    ),

	                array(
		                'id'       => 'border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Border Color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
	                ),
	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-top-drawer',
		                'type' => 'section',
		                'title' => esc_html__('Top Drawer', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id'       => 'top_drawer_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__( 'Top drawer background color', 'pithree' ),
		                'default'  => '#ffa60a',
		                'validate' => 'color',
	                ),

	                array(
		                'id'       => 'top_drawer_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top drawer text color', 'pithree'),
		                'default'  => '#2c3e50',
		                'validate' => 'color',
	                ),

	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-header-color',
		                'type' => 'section',
		                'title' => esc_html__('Header', 'pithree'),
		                'indent' => true
	                ),
	                $this->get_theme_color_enable('header_color_customize'),
	                array(
		                'id'       => 'header_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header background color', 'pithree'),
		                'default'  => '#fff',
		                'validate' => 'color',
		                'required'  => array('header_color_customize', '=', 1),
	                ),
	                array(
		                'id'        => 'header_overlay',
		                'type'      => 'slider',
		                'title'     => esc_html__('Header Overlay', 'pithree'),
		                'subtitle'  => esc_html__('Set the opacity level of the overlay', 'pithree'),
		                'default'   => '0',
		                'min'       => 0,
		                'step'      => 1,
		                'max'       => 100,
		                'required'  => array(
			                array('header_color_customize', '=', 1),
			                array('header_float', '=', 1),
		                ),
	                ),
	                array(
		                'id'       => 'header_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header text color', 'pithree'),
		                'default'  => '#8a8a8a',
		                'validate' => 'color',
		                'required'  => array('header_color_customize', '=', 1),
	                ),
	                array(
		                'id'       => 'header_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header border color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
		                'required'  => array('header_color_customize', '=', 1),
	                ),
	                array(
		                'id'       => 'header_above_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header above border color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
		                'required'  => array('header_color_customize', '=', 1),
	                ),

	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-top-bar',
		                'type' => 'section',
		                'title' => esc_html__('Top Bar', 'pithree'),
		                'indent' => true
	                ),
	                $this->get_theme_color_enable('top_bar_color_customize'),
	                array(
		                'id'       => 'top_bar_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__( 'Top bar background color', 'pithree' ),
		                'default'  => '#f1f1f1',
		                'validate' => 'color',
		                'required'  => array('top_bar_color_customize', '=', 1),
	                ),
	                array(
		                'id'        => 'top_bar_overlay',
		                'type'      => 'slider',
		                'title'     => esc_html__('Top bar overlay', 'pithree'),
		                'subtitle'  => esc_html__('Set the opacity level of the overlay.', 'pithree'),
		                'default'   => '0',
		                'min'       => 0,
		                'step'      => 1,
		                'max'       => 100,
		                'required'  => array(
			                array('top_bar_color_customize', '=', 1),
			                array('header_float', '=', 1),
		                ),
	                ),
	                array(
		                'id'       => 'top_bar_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top bar text color', 'pithree'),
		                'default'  => '#2c3e50',
		                'validate' => 'color',
		                'required'  => array('top_bar_color_customize', '=', 1),
	                ),
	                array(
		                'id'       => 'top_bar_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top bar border color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
		                'required'  => array('top_bar_color_customize', '=', 1),
	                ),

	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-navigation-color',
		                'type' => 'section',
		                'title' => esc_html__('Navigation', 'pithree'),
		                'indent' => true
	                ),
	                $this->get_theme_color_enable('navigation_color_customize'),
	                array(
		                'id'       => 'navigation_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Navigation background color', 'pithree'),
		                'default'  => '#fff',
		                'validate' => 'color',
		                'required'  => array('navigation_color_customize', '=', 1),
	                ),
	                array(
		                'id'        => 'navigation_overlay',
		                'type'      => 'slider',
		                'title'     => esc_html__('Navigation overlay', 'pithree'),
		                'subtitle'  => esc_html__('Set the opacity level of the overlay.', 'pithree'),
		                'default'   => '0',
		                'min'       => 0,
		                'step'      => 1,
		                'max'       => 100,
		                'required'  => array(
			                array('header_float', '=', 1),
			                array('navigation_color_customize', '=', 1),
		                )
	                ),
	                array(
		                'id'       => 'navigation_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Navigation text color', 'pithree'),
		                'default'  => '#8a8a8a',
		                'validate' => 'color',
		                'required'  => array('navigation_color_customize', '=', 1),
	                ),


	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-header-mobile',
		                'type' => 'section',
		                'title' => esc_html__('Header Mobile Color', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id'       => 'top_bar_mobile_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top bar background color', 'pithree'),
		                'default'  => '#fff',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'top_bar_mobile_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top bar text color', 'pithree'),
		                'default'  => '#8a8a8a',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'top_bar_mobile_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Top bar border bottom color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'header_mobile_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header background color', 'pithree'),
		                'default'  => '#fff',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'header_mobile_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header text color', 'pithree'),
		                'default'  => '#8a8a8a',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'header_mobile_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Header border bottom color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
	                ),

	                //--------------------------------------------------------------------
	                array(
		                'id' => 'section-theme-color-footer-color',
		                'type' => 'section',
		                'title' => esc_html__('Footer', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id'       => 'footer_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Footer background color', 'pithree'),
		                'default'  => '#1b2c3e',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'footer_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Footer text color', 'pithree'),
		                'default'  => '#979da4',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'footer_widget_title_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Footer widget title color', 'pithree'),
		                'default'  => '#fff',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'footer_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Footer border color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
	                ),
	                array(
		                'id' => 'section-theme-color-bottom-bar-color',
		                'type' => 'section',
		                'title' => esc_html__('Bottom Bar', 'pithree'),
		                'indent' => true
	                ),
	                array(
		                'id'       => 'bottom_bar_bg_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Bottom bar background color', 'pithree'),
		                'default'  => '#172737',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'bottom_bar_text_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Bottom bar text color', 'pithree'),
		                'default'  => '#979da4',
		                'validate' => 'color',
	                ),
	                array(
		                'id'       => 'bottom_bar_border_color',
		                'type'     => 'color',
		                'title'    => esc_html__('Bottom bar border color', 'pithree'),
		                'default'  => '#e0e0e0',
		                'validate' => 'color',
	                ),
                )
            );

	        // Font Options
            $this->sections[] = array(
                'icon' => 'el el-font',
                'title' => esc_html__('Font Options', 'pithree'),
                'desc'   => esc_html__( 'If you change value in this section, you must "Save & Generate CSS"', 'pithree' ),
                'fields' => array(
                    array(
                        'id'=>'body_font',
                        'type' => 'typography',
                        'title' => esc_html__('Body Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the body font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'text-align'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'line-height'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'14px',
                            'font-family'=>'Lato',
                            'font-weight'=>'400',
                            'google'      => true
                        ),
                    ),
	                array(
		                'id'=> 'secondary_font',
		                'type' => 'typography',
		                'title' => esc_html__('Secondary Font', 'pithree'),
		                'subtitle' => esc_html__('Specify the Secondary font properties.', 'pithree'),
		                'google' => true,
		                'fonts' => $fonts,
		                'line-height'=>false,
		                'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
		                'color'=>false,
		                'text-align'=>false,
		                'font-style' => false,
		                'subsets' => false,
		                'font-size' => false,
		                'font-weight' => false,
		                'output' => array(''), // An array of CSS selectors to apply this font style to dynamically
		                'compiler' => array(''), // An array of CSS selectors to apply this font style to dynamically
		                'units'=> 'px', // Defaults to px
		                'default' => array(
			                'font-family'=>'Lato',
		                ),
	                ),

                    array(
                        'id'=>'h1_font',
                        'type' => 'typography',
                        'title' => esc_html__('H1 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H1 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'text-align'=>false,
                        'line-height'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'36px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                    array(
                        'id'=>'h2_font',
                        'type' => 'typography',
                        'title' => esc_html__('H2 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H2 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'line-height'=>false,
                        'text-align'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'30px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                    array(
                        'id'=>'h3_font',
                        'type' => 'typography',
                        'title' => esc_html__('H3 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H3 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'text-align'=>false,
                        'line-height'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'24px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                    array(
                        'id'=>'h4_font',
                        'type' => 'typography',
                        'title' => esc_html__('H4 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H4 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'text-align'=>false,
                        'line-height'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'20px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                    array(
                        'id'=>'h5_font',
                        'type' => 'typography',
                        'title' => esc_html__('H5 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H5 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'line-height'=>false,
                        'text-align'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'16px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                    array(
                        'id'=>'h6_font',
                        'type' => 'typography',
                        'title' => esc_html__('H6 Font', 'pithree'),
                        'subtitle' => esc_html__('Specify the H6 font properties.', 'pithree'),
                        'google'=> true,
                        'fonts' => $fonts,
                        'line-height'=>false,
                        'text-align'=>false,
                        'color'=>false,
                        'letter-spacing'=>false,
                        'all_styles' => true, // Enable all Google Font style/weight variations to be added to the page
                        'output' => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler' => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'units'=>'px', // Defaults to px
                        'default' => array(
                            'font-size'=>'14px',
                            'font-family' => 'Lato',
                            'font-weight'=>'400',
                        ),
                    ),
                ),
            );

	        // Social Profiles
            $this->sections[] = array(
                'title'  => esc_html__( 'Social Profiles', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-path',
                'fields' => array_merge(g5plus_get_social_profiles(), array(
	                array(
		                'id'=>'social-profile-divide-0',
		                'type' => 'divide'
	                ),
	                array(
		                'title'    => esc_html__('Social Share', 'pithree'),
		                'id'       => 'social_sharing',
		                'type'     => 'checkbox',
		                'subtitle' => esc_html__('Show the social sharing in single blog and single product', 'pithree'),

		                //Must provide key => value pairs for multi checkbox options
		                'options'  => array(
			                'facebook' => 'Facebook',
			                'twitter' => 'Twitter',
			                'google' => 'Google',
			                'linkedin' => 'Linkedin',
			                'tumblr' => 'Tumblr',
			                'pinterest' => 'Pinterest'
		                ),

		                //See how default has changed? you also don't need to specify opts that are 0.
		                'default' => array(
			                'facebook' => '1',
			                'twitter' => '1',
			                'google' => '1',
			                'linkedin' => '1',
			                'tumblr' => '1',
			                'pinterest' => '1'
		                )
	                )
                ))
            );

	        // Woocommerce
            $this->sections[] = array(
                'title'  =>  esc_html__( 'Woocommerce', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-shopping-cart',
                'fields' => array(

	                $this->get_section_start('woocommerce_general',esc_html__('General','pithree')),
	                array(
		                'id'       => 'product_featured_label_enable',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Featured Label', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 1
	                ),

	                array(
		                'id'       => 'product_featured_label_text',
		                'type'     => 'text',
		                'title'    => esc_html__( 'Featured Label Text', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'default'  => 'Hot',
		                'required'  => array('product_featured_label_enable', '=', 1),
	                ),


	                array(
		                'id'       => 'product_sale_flash_mode',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Sale Flash Mode', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => array(
			                'text' => esc_html__('Text','pithree'),
			                'percent' => esc_html__('Percent','pithree'),
							'' => esc_html__('Disable','pithree')
		                ),
		                'default'  => 'percent',
	                ),

	                array(
		                'id'       => 'product_sale_label_text',
		                'type'     => 'text',
		                'title'    => esc_html__( 'Sale Label Text', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'default'  => 'Sale',
		                'required'  => array(
			                array('product_featured_label_enable', '=', 1),
			                array('product_sale_flash_mode', '=', 'text'),
		                )
	                ),


	                array(
		                'id'       => 'product_sale_count_down_enable',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Sale Count Down', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 1
	                ),


	                array(
		                'id'       => 'product_add_to_cart',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Add To Cart Button', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 1
	                ),

	                $this->get_section_start('archive_product',esc_html__('Shop and Category Page','pithree')),
	                array(
		                'id'       => 'product_catalog_style',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Product Catalog Style', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_product_catalog_style(),
		                'default'  => 'left'
	                ),

	                array(
		                'id' => 'product_display_columns',
		                'type' => 'select',
		                'title' => esc_html__('Product Display Columns', 'pithree'),
		                'subtitle' => esc_html__('Choose the number of columns to display on shop/category pages.','pithree'),
		                'options' => array(
			                '2'		=> '2',
			                '3'		=> '3',
			                '4'		=> '4',
			                '5'       => '5'
		                ),
		                'desc' => '',
		                'default' => '3',
		                'select2' => array('allowClear' =>  false) ,
	                ),

	                array (
		                'id' => 'product_per_page',
		                'type' => 'text',
		                'title'     => esc_html__('Products Per Page', 'pithree'),
		                'compiler' => true,
		                'validate' => 'comma_numeric',
		                'description' => __ ( 'Number of product that display per page. Default: 12', 'pithree' ),
		                'default' => '12'
	                ),

	                array(
		                'id'       => 'product_category_enable',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Category', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 1
	                ),

	                array(
		                'id'       => 'product_show_rating',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Rating', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 0
	                ),

	                array(
		                'id'       => 'product_quick_view_enable',
		                'type'     => 'button_set',
		                'title'    => esc_html__( 'Show Quick View', 'pithree' ),
		                'subtitle' => '',
		                'desc'     => '',
		                'options'  => g5plus_get_toggle(),
		                'default'  => 1
	                ),


	                $this->get_section_start('single_product',esc_html__('Single Product','pithree')),
	                array(
		                'id'       => 'related_product_count',
		                'type'     => 'text',
		                'title'    => esc_html__('Related Product Total Record', 'pithree'),
		                'subtitle' => esc_html__('Total Record Of Related Product.', 'pithree'),
		                'validate' => 'number',
		                'default'  => '6',
	                ),

	                array(
		                'id' => 'related_product_display_columns',
		                'type' => 'select',
		                'title' => esc_html__('Related Product Display Columns', 'pithree'),
		                'subtitle' => esc_html__('Choose the number of columns to display on related product.','pithree'),
		                'options' => array(
			                '3'		=> '3',
			                '4'		=> '4',
			                '5'		=> '5',
		                ),
		                'desc' => '',
		                'default' => '4'
	                ),

	                array(
		                'id' => 'related_product_condition',
		                'type' => 'checkbox',
		                'title' => esc_html__('Related Product Condition', 'pithree'),
		                'options' => array(
			                'category' => esc_html__('Same Category','pithree'),
			                'tag' => esc_html__('Same Tag','pithree'),
		                ),
		                'default' => array(
			                'category'      => '1',
			                'tag'      => '1',
		                ),
	                ),

	                array(
		                'id' => 'up_sells_product_display_columns',
		                'type' => 'select',
		                'title' => esc_html__('Up Sells Product Display Columns', 'pithree'),
		                'subtitle' => esc_html__('Choose the number of columns to display on up sells product.','pithree'),
		                'options' => array(
			                '3'		=> '3',
			                '4'		=> '4',
			                '5'		=> '5',
		                ),
		                'desc' => '',
		                'default' => '4'
	                ),
	                $this->get_section_start('cart_pages',esc_html__('Cart Page','pithree')),
	                array(
		                'id'       => 'cross_sells_product_count',
		                'type'     => 'text',
		                'title'    => esc_html__('Cross Sells Product Total Record', 'pithree'),
		                'subtitle' => esc_html__('Total Record Of Cross Sells Product.', 'pithree'),
		                'validate' => 'number',
		                'default'  => '6',
	                ),

	                array(
		                'id' => 'cross_sells_product_display_columns',
		                'type' => 'select',
		                'title' => esc_html__('Cross Sells Product Display Columns', 'pithree'),
		                'subtitle' => esc_html__('Choose the number of columns to display on cross sells product.','pithree'),
		                'options' => array(
			                '3'		=> '3',
			                '4'		=> '4',
			                '5'		=> '5',
		                ),
		                'desc' => '',
		                'default' => '4'
	                ),

                )
            );

			// Custom Post Type
            $this->sections[] = array(
                'title'  => esc_html__( 'Custom Post Type', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-screenshot',
                'fields' => array(
                    array(
                        'id' => 'cpt-disable',
                        'type' => 'checkbox',
                        'title' => esc_html__('Disable Custom Post Types', 'pithree'),
                        'subtitle' => esc_html__('You can disable the custom post types used within the theme here, by checking the corresponding box. NOTE: If you do not want to disable any, then make sure none of the boxes are checked.', 'pithree'),
                        'options' => array(
                            'portfolio' => 'Portfolio',
                            'services' => 'Our Services'
                        ),
                        'default' => array(
                            'portfolio' => '0',
                            'services' => '0',
                        )
                    ),


                )
            );

			// Portfolio Settings
			$this->sections[] = array(
				'title'  => esc_html__( 'Portfolio Settings', 'pithree' ),
				'desc'   => '',
				'icon'   => 'el el-th-large',
				'subsection' => true,
				'fields' => array(
					array(
						'id' => 'portfolio_view_all_cat_title',
						'type' => 'text',
						'title' => esc_html__('Title View all category', 'pithree'),
						'subtitle' => '',
						'desc' => '',
						'default' => esc_html__('All Porjects', 'pithree'),
					),
					array(
						'id' => 'portfolio_archive_page',
						'type' => 'select',
						'title' => esc_html__('Select portfolio archive page', 'pithree'),
						'desc' => '',
						'default' => '',
						'options'  => $this->get_pages()
					),
					array(
						'id' => 'portfolio-single-style',
						'type' => 'select',
						'title' => esc_html__('Select portfolio single layout', 'pithree'),
						'desc' => '',
						'default' => '',
						'options'  => array(
							'single-small' => esc_html__('Single small image','pithree'),
							'single-video' => esc_html__('Single video','pithree')
						),
						'select2'  => array('allowClear' => false),
						'default' => 'single-small',
					),
					array(
						'id' => 'portfolio_disable_link_detail',
						'type' => 'button_set',
						'title' => esc_html__('Disable link to detail', 'pithree'),
						'subtitle' => esc_html__('Enable/Disable link to detail in Portfolio', 'pithree'),
						'desc' => '',
						'options' => array('1' => 'On','0' => 'Off'),
						'default' => '0'
					),

				)
			);
			$this->sections[] = array(
				'title'  => esc_html__( 'Our Services', 'pithree' ),
				'desc'   => '',
				'icon'   => 'el el-network',
				'subsection' => true,
				'fields' => array(
					$this->get_section_start('archive_services',esc_html__('Archive Page','pithree')),
					array(
						'id' => 'custom_services_layout_style',
						'type' => 'select',
						'title' => esc_html__('Layout Style', 'pithree'),
						'subtitle' => esc_html__('Select layout style.', 'pithree'),
						'desc' => '',
						'default' => 'style1',
						'options'  => array(
							'style1' => esc_html__('Default', 'pithree'),
							'style2' => esc_html__('No border', 'pithree')
						)
					),
					array(
						'id' => 'custom_services_tab',
						'type' => 'button_set',
						'title' => esc_html__('Show Category?', 'pithree'),
						'subtitle' => esc_html__('Show Services Categories As Tabs.', 'pithree'),
						'default' => 1,
						'options'  => g5plus_get_toggle()
					),
					array(
						'id' => 'custom_services_column',
						'type' => 'select',
						'title' => esc_html__('Column(s)', 'pithree'),
						'default' => '3',
						'options'  => array( '2' => '2' , '3' => '3','4' => '4' )
					),
					array(
						'id' => 'custom_services_paging',
						'type' => 'select',
						'title' => esc_html__('Page Paging', 'pithree'),
						'default' => '',
						'options'  => array(
							'' => esc_html__('Show all', 'pithree'),
							'load-more' => esc_html__('Load more', 'pithree')
						)
					),
					array(
						'id' => 'custom_services_post_per_page',
						'type' => 'text',
						'title' => esc_html__('Post per Page', 'pithree'),
						'default' => 8,
						'required'  => array('custom_services_paging', '=', 'load-more')
					),
				)
			);
            $this->sections[] = array(
                'title'  => esc_html__( 'Resources Options', 'pithree' ),
                'desc'   => '',
                'icon'   => 'el el-th-large',
                'fields' => array(
                    array(
                        'id'        => 'cdn_bootstrap_js',
                        'type'      => 'text',
                        'title'     => esc_html__('CDN Bootstrap Script', 'pithree'),
                        'subtitle'  => esc_html__('Url CDN Bootstrap Script', 'pithree'),
                        'desc'      => '',
                        'default'   => '',
                    ),

                    array(
                        'id'        => 'cdn_bootstrap_css',
                        'type'      => 'text',
                        'title'     => esc_html__('CDN Bootstrap Stylesheet', 'pithree'),
                        'subtitle'  => esc_html__('Url CDN Bootstrap Stylesheet', 'pithree'),
                        'desc'      => '',
                        'default'   => '',
                    ),

                    array(
                        'id'        => 'cdn_font_awesome',
                        'type'      => 'text',
                        'title'     => esc_html__('CDN Font Awesome', 'pithree'),
                        'subtitle'  => esc_html__('Url CDN Font Awesome', 'pithree'),
                        'desc'      => '',
                        'default'   => '',
                    ),

                )
            );
            $this->sections[] = array(
                'title'  => esc_html__( 'Custom CSS & Script', 'pithree' ),
                'desc'   => esc_html__( 'If you change Custom CSS, you must "Save & Generate CSS"', 'pithree' ),
                'icon'   => 'el el-edit',
                'fields' => array(
                    array(
                        'id' => 'custom_css',
                        'type' => 'ace_editor',
                        'mode' => 'css',
                        'theme' => 'monokai',
                        'title' => esc_html__('Custom CSS', 'pithree'),
                        'subtitle' => esc_html__('Add some CSS to your theme by adding it to this textarea. Please do not include any style tags.', 'pithree'),
                        'desc' => '',
                        'default' => '',
                        'options'  => array('minLines'=> 20, 'maxLines' => 60)
                    ),
                    array(
                        'id' => 'custom_js',
                        'type' => 'ace_editor',
                        'mode' => 'javascript',
                        'theme' => 'chrome',
                        'title' => esc_html__('Custom JS', 'pithree'),
                        'subtitle' => esc_html__('Add some custom JavaScript to your theme by adding it to this textarea. Please do not include any script tags.', 'pithree'),
                        'desc' => '',
                        'default' => '',
                        'options'  => array('minLines'=> 20, 'maxLines' => 60)
                    ),

                )
            );
        }

        public function setHelpTabs() {
        }

        /**
         * All the possible arguments for Redux.
         * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
         * */
        public function setArguments() {

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $this->args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'           => 'g5plus_pithree_options',
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'       => $theme->get( 'Name' ),
                // Name that appears at the top of your panel
                'display_version'    => $theme->get( 'Version' ),
                // Version that appears at the top of your panel
                'menu_type'          => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'     => true,
                // Show the sections below the admin menu item or not
                'menu_title'         => esc_html__( 'Theme Options', 'pithree' ),
                'page_title'         => esc_html__( 'Theme Options', 'pithree' ),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key'     => '',
                // Must be defined to add google fonts to the typography module

                'async_typography'   => false,
                // Use a asynchronous font on the front end or font string
                'admin_bar'          => true,
                // Show the panel pages on the admin bar
                'global_variable'    => '',
                // Set a different name for your global variable other than the opt_name
                'dev_mode'           => false,
                // Show the time the page took to load, etc
                'customizer'         => true,
                // Enable basic customizer support

                // OPTIONAL -> Give you extra features
                'page_priority'      => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'        => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_theme_page#Parameters
                'page_permissions'   => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon'          => '',
                // Specify a custom URL to an icon
                'last_tab'           => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon'          => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug'          => '_options',
                // Page slug used to denote the panel
                'save_defaults'      => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show'       => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark'       => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export' => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time'     => 60 * MINUTE_IN_SECONDS,
                'output'             => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'         => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'           => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'system_info'        => false,
                // REMOVE

                // HINTS
                'hints'              => array(
                    'icon'          => 'icon-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'   => 'light',
                        'shadow'  => true,
                        'rounded' => false,
                        'style'   => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'mouseover',
                        ),
                        'hide' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'click mouseleave',
                        ),
                    ),
                )
            );
        }

    }

    global $reduxConfig;
    $reduxConfig = new Redux_Framework_options_config();
}