<?php
/**
 * The template for displaying archive pages
 *
 * Used to display archive-type pages if nothing more specific matches a query.
 * For example, puts together date-based pages if no date.php file exists.
 *
 * If you'd like to further customize these archive views, you may create a
 * new template file for each one. For example, tag.php (Tag archives),
 * category.php (Category archives), author.php (Author archives), etc.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Pithree
 * @since Pithree 1.0
 */

$wp_query = &G5Plus_Global::get_wp_query();
$page_layouts = &G5Plus_Global::get_page_layout();
$post_layouts = &G5Plus_Global::get_post_layout();

// set page layout
$layout = isset($_GET['layout']) ? $_GET['layout'] : '';
if (array_key_exists($layout,g5plus_get_page_layout())) {
	$page_layouts['layout'] = $layout;
}

// set sidebar_layout
$sidebar_layout = isset($_GET['sidebar-layout']) ? $_GET['sidebar-layout'] : '';
if(array_key_exists($sidebar_layout,g5plus_get_sidebar_layout())) {
	$page_layouts['sidebar_layout'] = $sidebar_layout;
}

// set sidebar_width
$sidebar_width = isset($_GET['sidebar-width']) ? $_GET['sidebar-width'] : '';
if (array_key_exists($sidebar_width,g5plus_get_sidebar_width())) {
	$page_layouts['sidebar_width'] = $sidebar_width;
}

// set post layout
$post_layout = isset($_GET['post-layout']) ? $_GET['post-layout'] : '';
if (array_key_exists($post_layout,g5plus_get_post_layout())) {
	$post_layouts['layout'] = $post_layout;
}

// set post column
$post_column = isset($_GET['column']) ? $_GET['column'] : '';
if (array_key_exists($post_column,g5plus_get_post_columns())) {
	$post_layouts['post_column'] = $post_column;
}

// set paging
$paging = isset($_GET['paging']) ? $_GET['paging'] : '';
if (array_key_exists($paging,g5plus_get_paging_style())) {
	$post_layouts['paging'] = $paging;
}

$has_sidebar = false;
$archive_inner_class = array('archive-inner');
if (is_active_sidebar($page_layouts['sidebar']) && ($page_layouts['sidebar_layout'] != 'none')) {
	$has_sidebar = true;
	$sidebar_col = 3;
	if ($page_layouts['sidebar_width'] == 'large') {
		$sidebar_col = 4;
	}
	$archive_inner_class[] = 'col-md-'. (12 - $sidebar_col);
	if ($page_layouts['sidebar_layout'] == 'left') {
		$archive_inner_class[] = 'col-md-push-' . $sidebar_col;
	}
}

$archive_wrap_class = array('archive-wrap');
$archive_wrap_class[] = 'archive-' . $post_layouts['layout'];
if (in_array($post_layouts['layout'],array('masonry'))) {
	$archive_wrap_class[] = 'archive-columns-' . $post_layouts['post_column'];
}

$custom_styles = array();

if (isset($page_layouts['padding']['padding-top']) && !empty($page_layouts['padding']['padding-top']) && ($page_layouts['padding']['padding-top'] != 'px') ) {
	$custom_styles[] = "padding-top:" . $page_layouts['padding']['padding-top'];
}

if (isset($page_layouts['padding']['padding-bottom']) && !empty($page_layouts['padding']['padding-bottom'])  && ($page_layouts['padding']['padding-bottom'] != 'px')) {
	$custom_styles[] = "padding-bottom:" . $page_layouts['padding']['padding-bottom'];
}


$custom_style= '';
if ($custom_styles) {
	$custom_style = 'style="'. join(';',$custom_styles).'"';
}

if(is_search()){
	$page_layouts['layout'] = 'container';
}

?>
<?php
/**
 * @hooked - g5plus_archive_heading - 5
 **/
do_action('g5plus_before_archive');
?>
<div id="primary-content" <?php echo wp_kses_post($custom_style); ?> class="<?php echo esc_attr(join(' ',$archive_wrap_class)); ?>">
	<?php if ($page_layouts['layout'] != 'full'): ?>
		<div class="<?php echo esc_attr($page_layouts['layout']) ?> clearfix">
	<?php endif;?>
			<?php if (($has_sidebar) && ($page_layouts['layout'] != 'full')): ?>
				<div class="row">
			<?php endif; ?>
				<div class="<?php echo esc_attr(join(' ',$archive_inner_class)); ?>">
					<div class="blog-wrap clearfix">
						<?php
						if ( have_posts() ) :
							// Start the Loop.
							while ( have_posts() ) : the_post();
								/*
								 * Include the post format-specific template for the content. If you want to
								 * use this in a child theme, then include a file called called content-___.php
								 * (where ___ is the post format) and that will be used instead.
								 */
								g5plus_get_template( 'archive/content-'. $post_layouts['layout'] );
							endwhile; ?>
					</div>
					<?php else :
						/*If no content, include the "No posts found" template.*/
						g5plus_get_template( 'archive/content-none');
					endif;?>
					<?php if ($wp_query->max_num_pages > 1) {
						switch($post_layouts['paging']){
							case 'load-more':
								g5plus_paging_load_more();
								break;
							case 'infinite-scroll':
								g5plus_paging_infinite_scroll();
								break;
							default:
								g5plus_paging_navigation();
								break;
						}
					}?>
				</div>
				<?php get_sidebar(); ?>

			<?php if (($has_sidebar) && ($page_layouts['layout'] != 'full')): ?>
				</div>
			<?php endif; ?>
	<?php if ($page_layouts['layout'] != 'full'): ?>
		</div>
	<?php endif;?>
</div>
