<?php
/**
 * The template for displaying pages
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages and that
 * other "pages" on your WordPress site will use a different template.
 *
 * @package WordPress
 * @subpackage Pithree
 * @since Pithree 1.0
 */
$page_layouts = &G5Plus_Global::get_page_layout();
$page_wrap_class = array('page-wrap');


// custom page layout
$layout = rwmb_meta(G5PLUS_METABOX_PREFIX.'layout');
if ($layout != '' && $layout != '-1') {
    $page_layouts['layout'] = $layout;
}

// custom sidebar layout
$sidebar_layout = rwmb_meta(G5PLUS_METABOX_PREFIX.'sidebar_layout');
if($sidebar_layout != '' && $sidebar_layout != '-1') {
    $page_layouts['sidebar_layout'] = $sidebar_layout;
}

// custom sidebar
$sidebar = rwmb_meta(G5PLUS_METABOX_PREFIX.'sidebar');
if ($sidebar != '' && $sidebar != '-1') {
	$page_layouts['sidebar'] = $sidebar;
}

// custom sidebar width
$sidebar_width = rwmb_meta(G5PLUS_METABOX_PREFIX.'sidebar_width');
if ($sidebar_width != '' && $sidebar_width != '-1') {
    $page_layouts['sidebar_width'] = $sidebar_width;
}

// custom sidebar mobile enable
$sidebar_mobile_enable = rwmb_meta(G5PLUS_METABOX_PREFIX.'sidebar_mobile_enable');
if ($sidebar_mobile_enable != '' && $sidebar_mobile_enable != '-1') {
	$page_layouts['sidebar_mobile_enable'] = $sidebar_mobile_enable;
}

$remove_content_padding = rwmb_meta(G5PLUS_METABOX_PREFIX.'remove_content_padding');
if ($remove_content_padding) {
	$page_wrap_class[] = 'padding-none';
}


// set page layout
$layout = isset($_GET['layout']) ? $_GET['layout'] : '';
if (array_key_exists($layout,g5plus_get_page_layout())) {
	$page_layouts['layout'] = $layout;
}

// set sidebar_layout
$sidebar_layout = isset($_GET['sidebar-layout']) ? $_GET['sidebar-layout'] : '';
if(array_key_exists($sidebar_layout,g5plus_get_sidebar_layout())) {
	$page_layouts['sidebar_layout'] = $sidebar_layout;
}

// set sidebar_width
$sidebar_width = isset($_GET['sidebar-width']) ? $_GET['sidebar-width'] : '';
if (array_key_exists($sidebar_width,g5plus_get_sidebar_width())) {
	$page_layouts['sidebar_width'] = $sidebar_width;
}


$has_sidebar = false;
$page_inner_class = array('page-inner');
if (is_active_sidebar($page_layouts['sidebar']) && ($page_layouts['sidebar_layout'] != 'none')) {
    $has_sidebar = true;
    $sidebar_col = 3;
    if ($page_layouts['sidebar_width'] == 'large') {
        $sidebar_col = 4;
    }
    $page_inner_class[] = 'col-md-'. (12 - $sidebar_col);
    if ($page_layouts['sidebar_layout'] == 'left') {
        $page_inner_class[] = 'col-md-push-' . $sidebar_col;
    }
}


$custom_styles = array();
if (!$remove_content_padding) {
	if (isset($page_layouts['padding']['padding-top']) && !empty($page_layouts['padding']['padding-top']) && ($page_layouts['padding']['padding-top'] != 'px') ) {
		$custom_styles[] = "padding-top:" . $page_layouts['padding']['padding-top'];
	}

	if (isset($page_layouts['padding']['padding-bottom']) && !empty($page_layouts['padding']['padding-bottom'])  && ($page_layouts['padding']['padding-bottom'] != 'px')) {
		$custom_styles[] = "padding-bottom:" . $page_layouts['padding']['padding-bottom'];
	}
}

$custom_style= '';
if ($custom_styles) {
	$custom_style = 'style="'. join(';',$custom_styles).'"';
}

?>
<?php
/**
 * @hooked - g5plus_page_heading - 5
 **/
do_action('g5plus_before_page');
?>
<div id="primary-content" class="<?php echo join(' ',$page_wrap_class); ?>" <?php echo wp_kses_post($custom_style); ?>>
	<?php if ($page_layouts['layout'] != 'full'): ?>
		<div class="<?php echo esc_attr($page_layouts['layout']) ?> clearfix">
	<?php endif;?>
         <?php if (($has_sidebar) && ($page_layouts['layout'] != 'full')): ?>
            <div class="row">
         <?php endif; ?>
            <div class="<?php echo esc_attr(join(' ',$page_inner_class)); ?>">
                 <?php
                 // Start the loop.
                 while ( have_posts() ) : the_post();
                     // Include the page content template.
                     g5plus_get_template('content-page');
                     // End of the loop.
                 endwhile;
                 ?>
            </div>
            <?php get_sidebar(); ?>
         <?php if (($has_sidebar) && ($page_layouts['layout'] != 'full')): ?>
            </div>
         <?php endif; ?>
			<?php if ($page_layouts['layout'] != 'full'): ?>
        </div>
    <?php endif; ?>
</div>
